/*
  Provede zkontrolování, zda ve vazební tabulce není pro daný doklad/položku dokladu vazba.
  Pokud je, vyhodí to výjimku.
  
  Parametry:
  * i_idDokl   - id dokladu, u položky dokladu je to id položky
  * i_isDoklad - true, pokud se jedná o doklad, false, pokud se jedná o položku dokladu
  * i_modul    - modul dokladu či položky dokladu  
  
  Návratová hodnota:
  * true  - nenalezen záznam ve vazebním souboru
  * false - chyba, ve vazebním souboru nalezen záznam pro danou položku   
  
  Autor: Pavel Cvrček
*/

CREATE OR REPLACE FUNCTION dzkontrolujvazebnitab(i_iddokl integer, i_isdoklad boolean, i_modul character varying)
  RETURNS boolean AS $$  
declare  
  _pocetVazeb integer;  
begin  
    
  /* Jedná se o položku dokladu */  
  if (i_isDoklad = false) then  
    /* idtaba i idtabb jsou položky */  
    select count(*) into _pocetVazeb from dVazebTab where (typvazbyk in ('typVazbyDokl.polozkaSkl',  
                                                             'typVazbyDokl.polozkaSklSada', 'typVazbyDokl.polozkaSklKus', 'typVazbyDokl.polozkaSklPrevod',
                                                             'typVazbyDokl.obchod_obchod_pol', 'typVazbyDokl.obchod_faktura_pol',  
                                                             'typVazbyDokl.obchod_zaloha_pol', 'typVazbyDokl.obchod_sklad_pol'))  
                                                      and ((idtaba = i_idDokl and modula = i_modul) or (idtabb = i_idDokl and modulb = i_modul));  
    if (_PocetVazeb <> 0) then  
      return false;  
    end if;  
      
    /* kontrola, kde je pro položku dokladu jen u idtaba, jedná se o "typVazbyDokl.odpocetZALOHY" a "typVazbyDokl.odpocetZDD" */  
    select count(*) into _pocetVazeb from dVazebTab where (typvazbyk = 'typVazbyDokl.odpocetZALOHY' or typvazbyk = 'typVazbyDokl.odpocetZDD')  
                                                      and ((idtaba = i_idDokl and modula = i_modul and modulb = i_modul));  
    if (_pocetVazeb <> 0) then  
      return false;  
    end if;  
      
    return true;  
  else  
    
   /* Jedná se o doklad, kde je hlavička */  
   select count(*) into _pocetVazeb from dVazebTab where (typvazbyk not in ('typVazbyDokl.polozkaSkl',  
                            'typVazbyDokl.polozkaSklSada', 'typVazbyDokl.polozkaSklKus', 'typVazbyDokl.polozkaSklPrevod', 
                            'typVazbyDokl.obchod_obchod_pol', 'typVazbyDokl.obchod_faktura_pol',  
                            'typVazbyDokl.obchod_zaloha_pol', 'typVazbyDokl.obchod_sklad_pol')  
                        ) and (not (  
                            (modula='FAV' and modulb='FAV' and typvazbyk='typVazbyDokl.odpocetZALOHY') or  
                            (modula='FAV' and modulb='FAV' and typvazbyk='typVazbyDokl.odpocetZDD') or  
                            (modula='FAP' and modulb='FAP' and typvazbyk='typVazbyDokl.odpocetZALOHY') or  
                            (modula='FAP' and modulb='FAP' and typvazbyk='typVazbyDokl.odpocetZDD'))) and  
                        ((idtaba = i_idDokl and modula = i_modul) or (idtabb = i_idDokl and modulb=i_modul));  
   if (_pocetVazeb <> 0) then  
     return false;  
   end if;  
       
   return true;  
  end if;  
end;  
$$ LANGUAGE plpgsql;

ALTER FUNCTION public.dzkontrolujvazebnitab(i_iddokl integer, i_isdoklad boolean, i_modul character varying) OWNER TO %firmaRole%;
