--------------------------------------------------------------------------------
-- Bug 46510 - Přidat validaci zabraňující vytvoření rekurzivní definice sady/kompletu
--------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION isrekurzesada(_idceniksada INTEGER, _idcenik INTEGER) RETURNS BOOLEAN AS $$
DECLARE
  _id integer;
  _stack integer[];
  _nodes integer[];
  _items integer[];
BEGIN
  _stack := array[ _idceniksada, _idcenik ];

  --BFS algoritmus
  LOOP
    --bereme dalsi ID z vrcholu zasobniku
    _id := _stack[1];
    _stack := _stack[2:array_upper(_stack, 1)];

    --uz neni co kontrolovat
    if _id is null then
      exit;
    end if;
    --preskoc jiz zkontrolovane ceniky
    if _id = any( _nodes ) then
      continue;
    end if;

    --zjisteni polozek sady
    select array( select distinct idcenik from csady where idceniksada = _id ) into _items;
    --raise notice '_nodes=%, _stack=%, _id=%, _items=%', _nodes, _stack, _id, _items;

    --nalezeni rekurzivni zavislosti
    if _idceniksada = any( _items ) then
      return true;
    end if;

    _nodes := _nodes || _id;
    _stack := _items || _stack;

  END LOOP;

  RETURN FALSE;
END;
$$ LANGUAGE plpgsql;
ALTER FUNCTION isrekurzesada(INTEGER,INTEGER) OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION isrekurzesada() RETURNS TRIGGER AS $$
BEGIN
  IF isrekurzesada(NEW.idceniksada, NEW.idcenik) THEN
    RAISE EXCEPTION '0011:Nelze vytvořit položku sady, která nepřímo obsahuje nadřazený ceník.';
  END IF;

  RETURN NEW;
END;
$$LANGUAGE plpgsql;
ALTER FUNCTION isrekurzesada() OWNER TO %firmaRole%;

CREATE TRIGGER csadyisrekurzesada BEFORE INSERT ON csady
  FOR EACH ROW EXECUTE PROCEDURE isrekurzesada();

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
 values (nextval('seq_dbversion'), 1087, 't', %appVersion%, clock_timestamp());