--------------------------------------------------------------------------------
-- Bug 15742 – [WinStrom] Kalkulačka pro výpočet mzdy
--------------------------------------------------------------------------------

-- přidání polí do řádků mzdové kalkulačky
ALTER TABLE pmzdcalc ADD COLUMN koeficient3 numeric(19,6) NOT NULL DEFAULT 0.0;
ALTER TABLE pmzdcalc ADD COLUMN polein2 character varying(255);
ALTER TABLE pmzdcalc ADD COLUMN idmzdslozin2 integer;

CREATE INDEX pMzdCalc_IdMzdSlozIn2_index ON pMzdCalc USING btree (IdMzdSlozIn2);

-- přidání tabulky inicializačních řádek do kalkulačky
CREATE SEQUENCE seq_pmzdcalcinit
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;
ALTER TABLE public.seq_pmzdcalcinit OWNER TO %firmaRole%;

CREATE TABLE pmzdcalcinit
(
  idmzdcalcinit integer DEFAULT nextval('seq_pmzdcalcinit'::regclass) NOT NULL,
  lastupdate timestamp without time zone NOT NULL DEFAULT '2008-01-01 00:00:00'::timestamp without time zone,
  kod character varying(20) NOT NULL,
  nazev character varying(255) NOT NULL,
  nazeva character varying(255),
  nazevb character varying(255),
  nazevc character varying(255),
  popis text,
  poznam text,
  "show" boolean NOT NULL DEFAULT true,
  cisrad integer NOT NULL DEFAULT 0,
  polein character varying(255) NOT NULL,
  poleout character varying(255) NOT NULL,
  zdrojk character varying(50),
  platnostk character varying(50),
  idtyppracpom integer,
  idmzdslozout integer NOT NULL,
  idmzdcalchlav integer NOT NULL,
  CONSTRAINT pmzdcalcinit_pkey PRIMARY KEY (idmzdcalcinit),
  CONSTRAINT fk7549e7ec39186a54 FOREIGN KEY (idtyppracpom)
      REFERENCES ptyppracpom (idtyppracpom) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk7549e7ec59ac65b4 FOREIGN KEY (idmzdcalchlav)
      REFERENCES pmzdcalchlav (idmzdcalchlav) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk7549e7ecffa59017 FOREIGN KEY (idmzdslozout)
      REFERENCES pcismzdsloz (idcismzdsloz) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
);
ALTER TABLE pmzdcalcinit OWNER TO %firmaRole%;

CREATE INDEX pMzdCalcInit_IdMzdCalcHlav_index ON pMzdCalcInit USING btree (IdMzdCalcHlav);
CREATE INDEX pMzdCalcInit_IdTypPracPom_index ON pMzdCalcInit USING btree (IdTypPracPom);
CREATE INDEX pMzdCalcInit_IdMzdSlozOut_index ON pMzdCalcInit USING btree (IdMzdSlozOut);

-- uprava triggeru mazajiciho mzdove slozky pri smazani pracovniho pomeru, aby smazal vsechny pro osobu pokud to byl jediny pracovni pomer
CREATE OR REPLACE FUNCTION ppracpomhlavdeleteslozky()
  RETURNS trigger AS $$
declare
  pomeru integer;
begin
  delete from pmzdsloz where idpracpom = OLD.idpracpomhlav;
  delete from psmeny where idpracpom = OLD.idpracpomhlav;
  
  select count(*) into pomeru from ppracpomhlav where idpracpomhlav <> OLD.idpracpomhlav and idosoba = OLD.idosoba;
  if (pomeru = 0) then
    delete from pmzdsloz where idosoba = OLD.idosoba;
  end if;

  return OLD;
end;
$$ LANGUAGE plpgsql;

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 217, 't');
