/*
 Funkce provede vrcen sla dokladu z aplikace. Vrac inforamaci, zda se slo povedlo vrtit i nikoliv.
   
 Vstupn parametry:
 - i_idRady       - id pslun ady
 - i_idUcetObdobi - id etnho obdob
 - i_CisDokl      - slo vracenho dokladu
  
 Autor verze pro PostgreSQL:     Pavel Cvrek
 Autor pvodn verze pro Sybase: Josef Weinreb
*/

create or replace function dVratCisDokl (in i_idRady integer,in i_idUcetObdobi integer,in i_CisDokl varchar(20)) returns boolean as $$
declare
  _CisDelka integer;
  _ZobrazNuly boolean;
  _Prefix varchar(8);
  _Postfix varchar(8);
  _CisAkt integer;
  _unique boolean;
  _modul varchar;
  _typPohybu varchar;
  _idRadyDiry integer;
  _idRadyRok integer;
  _CisPoc integer;
  _idRady integer;
  _idUcetObdobi integer;
  _idRadyDiryT integer;

  _CisDokl varchar(20);
begin
  /** Nejprve se zkontroluj vstupn parametry **/    
  
  /* Id dokladov ady nesm bt null */
  /* !!! Dleit !!! Podmnky na nsledujcch dcch nevyhazuj vjimku kvli
     importu z W6 na W10. */
  if (i_idRady is null) then
    return true;
    /*raise exception 'dVratCisDokl(): Vstupn slo dokladov ady nesm bt przdn!';*/
  end if;
  
  /* Kontrola existence id ady */
  select idRady into _idRady from dRady where idRady = i_idRady;
  if (_idRady is null) then
    return true;
    /*raise exception 'dVratCisDokl(): Pokus o vrcen sla do dokladov ady, kter neexistuje!';*/
  end if;
  
  if (i_idUcetObdobi is null) then
    raise exception 'dVratCisDokl(): slo vstupnho etnho obdob je null!';
  end if;
  
  select idUcetObdobi into _idUcetObdobi from nUcetObdobi where idUcetObdobi=i_idUcetObdobi;
  if (_idUcetObdobi is null) then
    raise exception 'dVratCisDokl(): slo vstupnho etnho obdob neodpovd existujcmu etnmu obdob!';
  end if;
  
  /** Konec striktn kontroly vstupncch daj **/
  
  /* Zjist se slo, kter je na vrcholu dokladov ady pro etn obdob */
  select CisDelka,ZobrazNuly,CisAkt,CisPoc,Prefix,Postfix,idRadyRok into _CisDelka,_ZobrazNuly,_CisAkt,_CisPoc,_Prefix,_Postfix,
    _idRadyRok from dRadyRok where idRady = i_idRady and idUcetObdobi = i_idUcetObdobi for update;
  
  /* Zjist se modul a typ pohybu, pro kterou ada je. */
  select modul into _modul from dRady where idRady = i_idRady;
  
  /* Vytvo nov slo podle vrcholu s. ady pro porovnn */
  _CisDokl:= (select dVytvorCisDokl(_Prefix,_CisAkt,_Postfix,_ZobrazNuly,_CisDelka,i_idUcetObdobi));        
  
  /* Porovnm slo z vrcholu ady s navrcenm slem. Pokud se jedn o posledn slo ady, jednodue snm ta,
     protoe novj slo nebylo piazeno. Pokud ne, vlom slo do seznamu dr.*/
  if (rtrim(_CisDokl) = rtrim(i_CisDokl)) then
     update dRadyDiry set LastUpdate=now() where idRadyRok = _idRadyRok and cisdira = _CisDokl;
     
     /* Pokud se mae doklad, kter je na vrcholu a nen v de */
     select idRadyDiry into _idRadyDiryT from dRadyDiry where cisdira = _CisDokl and idRadyRok = _idRadyRok and LastUpdate<=now();
     if (_idRadyDiryT is null and _CisAkt <> _CisPoc) then
       _CisAkt:= _CisAkt - 1;
     end if;
     
     loop
       _CisDokl:= (select dVytvorCisDokl(_Prefix,_CisAkt,_Postfix,_ZobrazNuly,_CisDelka,i_idUcetObdobi));
       select idRadyDiry into _idRadyDiry from dRadyDiry where cisdira = _CisDokl and idRadyRok = _idRadyRok and LastUpdate<=now();
       if (_idRadyDiry is not null) then
         delete from dRadyDiry where cisdira = _CisDokl and idRadyRok = _idRadyRok and LastUpdate<=now();
         
         /* Kontrola, aby nedolo k peteen potku. */
         if (_CisAkt <> _CisPoc) then
           _CisAkt:= _CisAkt - 1;
         end if;
       else       
         exit;
       end if;
     end loop;
    
     update dRadyRok set cisAkt = _cisAkt where idRadyRok = _idRadyRok;
  else
    /* Nejsem na vrcholu rady - zmnm rezervaci na dru nebo dru zalom, pi opakovanm voln dru nevytvom */
    select idRadyDiry into _idRadyDiry from dRadyDiry where idRadyRok = _idRadyRok and CisDira = i_CisDokl;
    if(_idRadyDiry is null) then
      insert into dRadyDiry( idRadyRok,CisDira,LastUpdate) values( _idRadyRok,i_CisDokl,now());
    else
      update dRadyDiry set LastUpdate = now() where idRadyDiry = _idRadyDiry;
    end if;
  end if;
  
  return true;
end;
$$ LANGUAGE plpgsql;

insert into dbversion(iddbversion, dbversion, needreimport) values (nextval('seq_dbversion'), 27, 't');
