--------------------------------------------------------------------------------
-- Bug 18563 – [WinStrom] Pridat tabulku mapovani skladu
--------------------------------------------------------------------------------

CREATE SEQUENCE seq_smapsklad
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;
ALTER TABLE public.seq_smapsklad OWNER TO %firmaRole%;

create table smapsklad
(
    idmapsklad integer DEFAULT nextval('seq_smapsklad'::regclass) NOT NULL,
    lastupdate timestamp without time zone NOT NULL DEFAULT '2008-01-01 00:00:00'::timestamp without time zone,
    idstred integer,
    idskupzboz integer,
    idcenik integer,
    idsklad integer not null,
    CONSTRAINT smapsklad_pkey PRIMARY KEY (idmapsklad),
    CONSTRAINT smapsklad_idstred FOREIGN KEY (idstred)
      REFERENCES ustrediska (idstred) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
    CONSTRAINT smapsklad_idskupzboz FOREIGN KEY (idskupzboz)
      REFERENCES cskupzboz (idskupzboz) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
    CONSTRAINT smapsklad_idcenik FOREIGN KEY (idcenik)
      REFERENCES ccenik (idcenik) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
    CONSTRAINT smapsklad_idsklad FOREIGN KEY (idsklad)
      REFERENCES dtypdokl (idtypdokl) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
    CONSTRAINT smapsklad_unique_key UNIQUE (idstred, idskupzboz, idcenik)
);
ALTER TABLE smapsklad OWNER TO %firmaRole%;

CREATE INDEX smapsklad_idstred_index ON smapsklad USING btree (idstred);
CREATE INDEX smapsklad_idskupzboz_index ON smapsklad USING btree (idskupzboz);
CREATE INDEX smapsklad_idcenik_index ON smapsklad USING btree (idcenik);
CREATE INDEX smapsklad_idsklad_index ON smapsklad USING btree (idsklad);

CREATE OR REPLACE FUNCTION getPrefIdSkladu(_idStred integer, _idSkupZboz integer, _idCenik integer)
  RETURNS integer AS
$BODY$
declare
  result integer;
begin
  result = null;

  -- hledame podle strediska a ceniku 		|| str, cen
  if (_idStred is not null and _idCenik is not null) then
    result = (select idsklad from smapsklad where idstred = _idStred and idcenik = _idCenik);
  end if;

  -- hledame podle ceniku			|| *, cen
  if (result is null and _idCenik is not null) then
    result = (select idsklad from smapsklad where idstred is null and idcenik = _idCenik);
  end if;

  -- hledame podle strediska a skupiny zbozi	|| str, sku
  if (result is null and _idStred is not null and _idSkupZboz is not null) then
    result = (select idsklad from smapsklad where idstred = _idStred and idskupzboz = _idSkupZboz);
  end if;

  -- hledame podle skupiny zbozi		|| *, sku
  if (result is null and _idSkupZboz is not null) then
    result = (select idsklad from smapsklad where idstred is null and idskupzboz = _idSkupZboz);
  end if;

  -- hledame podle strediska			|| str, *, *
  if (result is null and _idStred is not null) then
    result = (select idsklad from smapsklad where idstred = _idStred and idskupzboz is null and idcenik is null);
  end if;

  -- hledame vseobecne pravidlo			|| *, *, *
  if (result is null) then
    result = (select idsklad from smapsklad where idstred is null and idskupzboz is null and idcenik is null);
  end if;

  return result;
end;
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION getPrefIdSkladu(integer, integer, integer) OWNER TO %firmaRole%;


CREATE OR REPLACE FUNCTION dpolskladinsertkusovnik()
  RETURNS trigger AS
$BODY$
declare
    _typPohybuK varchar;
    _typZasobyK varchar;
    _idKusovnik integer;
    _iducetobdobi integer;
    _stavNaSklade numeric;
    _sklKarta record;
    _cenik record;
    _sklzapor boolean;
    _idVydejPolSklad integer;
    _idParovanyDoklad integer;
    potKus record;
    _parKusMnoz numeric;
    _i integer;
    _kurz numeric;
    _isCiziMena boolean;
    _idMeny integer;
    _mnozMj numeric;
    _cenaMj numeric;
    _sumZkl numeric;
    _newSumZkl numeric;
    _sumZklMen numeric;
    _idSkladPotKus integer;
begin
  -- napriklad pokud se jedna o prevodku mezi sklady nechceme z prijemky vytvaret prevodku
  if (NEW.prevodka = true) then
    return NEW;
  end if;

  -- typem pohybu musi byt prijem
  select typpohybuk into _typPohybuK from ddoklsklad d where d.iddoklsklad = NEW.iddoklsklad;
  if (_typPohybuK <> 'typPohybu.prijem') then
    return NEW;
  end if;

  -- idcenik odkazuje na neco co je soucasti kusovniku.
  select ckus.idkusovnik into _idKusovnik from ckusovnik ckus where ckus.idcenik = NEW.idcenik
    and exists (select 1 from ckusovnik cPot where cPot.idotec = ckus.idkusovnik);
  if (_idKusovnik is null) then
    return NEW;
  end if;

  -- vytvorime nebo nalezneme zparovany doklad skl vydej
  select findparovanydoklsklad(NEW.iddoklsklad, NEW.modul, 'typVazbyDokl.hlavaSklKus') into _idParovanyDoklad;
  if (_idParovanyDoklad is null) then
    select createdoklsklad(NEW.idpolsklad, NEW.iddoklsklad, NEW.modul) into _idParovanyDoklad;
  end if;

  select isDoklSkladMenaCizi(_idParovanyDoklad, NEW.datVyst) into _isCiziMena;
  select getkurzfromdoklad(_idParovanyDoklad, NEW.datVyst) into _kurz;
  select idMeny into _idMeny from dDoklSklad where idDoklSklad = _idParovanyDoklad;

  _i = 0;
  _newSumZkl = 0.0;

  perform putglotxvariable('zurnalTxName', 'rozpadKusovniku');

  -- pro vsechny kusovniky, ktere jsou pod nasim kusovnikem a jsou skladove nebo vyroba
  for potKus in (select * from ckusovnik cPot where cPot.idotec = _idKusovnik) loop
    select * into _cenik from cCenik where idCenik = potKus.idCenik;

    select typZasobyK into _typZasobyK from cCenik cen where cen.idCenik = potKus.idCenik;
    if (_typZasobyK <> 'typZasoby.skladem' and _typZasobyK <> 'typZasoby.vyrobek') then
        _newSumZkl = _newSumZkl + _cenik.nakupcena * potKus.mnoz;
        continue;
    end if;
    _i = _i + 1;

    select findIdUcetniObdobiKDatu(NEW.datVyst) into _iducetobdobi;
    -- vybereme skladovou kartu podle preferovaneho skladu
    select null into _sklKarta;
    _idSkladPotKus = null;

    select getPrefIdSkladu(
	(select idstred from ddoklsklad where iddoklsklad = NEW.iddoklsklad),
	_cenik.idskupzboz, potKus.idcenik) into _idSkladPotKus;

    if (_idSkladPotKus is not null) then
	select * into _sklKarta from skarty where idcenik = potKus.idcenik and idtypdokl = _idSkladPotKus and iducetobdobi = _iducetobdobi;
    end if;

    -- sklad karta nebyla nalezena podle preferovaneho skladu, vezmeme sklad stejny jako z vytvarene polozky
    if (_sklKarta is null) then
	select * into _sklKarta from skarty where idcenik = potKus.idcenik and idtypdokl = NEW.idskladu and iducetobdobi = _iducetobdobi;
    end if;

    -- skladovou
    if (_sklKarta is null) then
	raise exception 'Nebyla nalezena skladova karta k polozce ceniku %. Definujte mapovani skladu pro tuto polozku nebo ji pridejte na sklad %',
		_cenik.kod, (select kod from dtypdokl where idtypdokl = NEW.idskladu);
    end if;

    select mnoz into _parKusMnoz from ckusovnik where idkusovnik = _idKusovnik;

   _mnozMj = (potKus.mnoz / _parKusMnoz) * NEW.mnozMj;
   _cenaMj = _sklKarta.prumCenaTuz / _kurz;
   _sumZkl = _mnozMj * _sklKarta.prumCenaTuz;
   _newSumZkl = _newSumZkl + _sumZkl;

   if(_isCiziMena) then
     _sumZklMen = _mnozMj * _cenaMj;
   else
     _sumZklMen = 0.0;
   end if;

    -- TODO doplnit sarze a expirace
    select dgetstavnasklade(_sklKarta.idkarty, NEW.datVyst, -1, NEW.idfirmy, NULL, NULL) into _stavNaSklade;

    -- osetreni zda je povoleny zaporny stav na sklade
    if (_stavNaSklade - _mnozMj < 0) then
        select sklzapor into _sklzapor from nNastav where NEW.datVyst >= PlatiOdData order by PlatiOdData desc limit 1;
        if (_sklzapor is null) then
            select sklzapor into _sklzapor from nNastav where PlatiOdData is null limit 1;
        end if;
        if _sklzapor is null or _sklzapor = false then
            raise exception '0002:sPreporctiSkladKartu: neni povolen zaporny stav skladu';
        end if;
    end if;

    select nextval('seq_dpolsklad'::regclass) into _idVydejPolSklad;

    insert into dpolsklad(idPolSklad, idcenik, idskladu, idkarty, datVyst, datUcto, modul, typPolozkyK, idDoklSklad,
        mnozMj, cenaMj, sumZkl, sumZklMen, idZklMdUcet, idZklDalUcet, kopZklMdUcet, kopZklDalUcet, baleniid, mnozBaleni,
        nazev, nazevA, nazevB, nazevC, sarze, expirace, cisRad, ucetni, idStred, idZakazky, idMeny)
    values (_idVydejPolSklad, potKus.idcenik, _sklKarta.idtypdokl, _sklKarta.idkarty, NEW.datVyst, NEW.datUcto, NEW.modul, NEW.typpolozkyk, _idParovanyDoklad,
        _mnozMj, _cenaMj, _sumZkl, _sumZklMen, NEW.idzkldalucet, NEW.idzklmducet, false, false, NEW.baleniid, NEW.mnozbaleni,
        _cenik.nazev, _cenik.nazevA, _cenik.nazevB, _cenik.nazevC, NULL, NULL, NEW.cisRad * 100 + _i, true,
        NEW.idStred, NEW.idZakazky, _idMeny);

    insert into dvazebtab (castka, idtabA, idtabB, modulA, modulB, storno, typVazbyK)
      values (0.0, NEW.idpolsklad, _idVydejPolSklad, 'SKL', 'SKL', false, 'typVazbyDokl.polozkaSklKus');

  end loop;

  perform removeglotxvariable('zurnalTxName');

  select getkurzfromdoklad(NEW.iddoklsklad, NEW.datvyst) into _kurz;
  _cenaMj = _newSumZkl / NEW.mnozMj / _kurz;

  select isDoklSkladMenaCizi(NEW.iddoklsklad, NEW.datVyst) into _isCiziMena;
  if (_isCiziMena) then
    _sumZklMen = NEW.cenaMj * NEW.mnozMj;
  else
    _sumZklMen = 0.0;
  end if;

  update dpolsklad set sumzkl = _newSumZkl, cenaMj = _cenaMj, sumZklMen = _sumZklMen where idpolsklad = NEW.idpolsklad;

  return NEW;
end;
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION dpolskladinsertkusovnik() OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION errorInInsertKusovnik(_iddoklsklad integer, _datvyst date, _idcenik integer, _idskladu integer, _prevodka boolean)
  RETURNS character varying AS
$BODY$
declare
  _typPohybuK character varying;
  _typZasobyK character varying;
  _idKusovnik integer;
  potKus record;
  _cenik record;
  _sklKarta record;
  _iducetobdobi integer;
  _idSkladPotKus integer;
begin
  -- napriklad pokud se jedna o prevodku mezi sklady nebudeme z prijemky vytvaret prevodku
  if (_prevodka = true) then
    return null;
  end if;

  -- typem pohybu musi byt prijem
  select typpohybuk into _typPohybuK from ddoklsklad d where d.iddoklsklad = _iddoklsklad;
  if (_typPohybuK <> 'typPohybu.prijem') then
    return null;
  end if;

  -- idcenik odkazuje na neco co je soucasti kusovniku.
  select ckus.idkusovnik into _idKusovnik from ckusovnik ckus where ckus.idcenik = _idcenik
    and exists (select 1 from ckusovnik cPot where cPot.idotec = ckus.idkusovnik);
  if (_idKusovnik is null) then
    return null;
  end if;

  -- pro vsechny kusovniky, ktere jsou pod nasim kusovnikem a jsou skladove nebo vyroba
  for potKus in (select * from ckusovnik cPot where cPot.idotec = _idKusovnik) loop
    select * into _cenik from cCenik where idCenik = potKus.idCenik;

    select typZasobyK into _typZasobyK from cCenik cen where cen.idCenik = potKus.idCenik;
    if (_typZasobyK <> 'typZasoby.skladem' and _typZasobyK <> 'typZasoby.vyrobek') then
        continue;
    end if;

    select findIdUcetniObdobiKDatu(_datvyst) into _iducetobdobi;
    -- vybereme skladovou kartu podle preferovaneho skladu
    select null into _sklKarta;
    _idSkladPotKus = null;

    select getPrefIdSkladu(
	(select idstred from ddoklsklad where iddoklsklad = _iddoklsklad),
	_cenik.idskupzboz, potKus.idcenik) into _idSkladPotKus;

    if (_idSkladPotKus is not null) then
	select * into _sklKarta from skarty where idcenik = potKus.idcenik and idtypdokl = _idSkladPotKus and iducetobdobi = _iducetobdobi;
    end if;

    -- sklad karta nebyla nalezena podle preferovaneho skladu, vezmeme sklad stejny jako z vytvarene polozky
    if (_sklKarta is null) then
	select * into _sklKarta from skarty where idcenik = potKus.idcenik and idtypdokl = _idskladu and iducetobdobi = _iducetobdobi;
    end if;

    -- skladovou
    if (_sklKarta is null) then
	return 'Nebyla nalezena skladova karta k polozce ceniku %. Definujte mapovani skladu pro tuto polozku nebo ji pridejte na sklad %',
		_cenik.kod, (select kod from dtypdokl where idtypdokl = _idskladu);
    end if;
  end loop;

  return null;
end;
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION errorInInsertKusovnik(integer, date, integer, integer, boolean) OWNER TO %firmaRole%;

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 272, 't');
