---------------------------------------------------------------------
-- Bug 11301 – [WinStrom] V okne vazeb na dokladu neni indikace storna
---------------------------------------------------------------------

-- pokud chceme opravit typ musime ho smazat, ale nejprve smazeme funkci, co ho
-- pouziva a pak typ, typ zalozime a zalozime i funkci (taky zmeneno character varying na text)
DROP FUNCTION public.findvazbydokladu(_iddokl integer, _modul character varying);
DROP TYPE vazbadokladu;

CREATE TYPE vazbadokladu AS (
	idvazebnidoklad integer,
	datucto timestamp without time zone,
	datvyst timestamp without time zone,
	iddokl integer,
	kod character varying(255),
	modul character varying(255),
	modulk character varying(255),
	popis text,
	poznam text,
	sumcelkem double precision,
	sumcelkemmen double precision,
	typvazbyk character varying(255),
        storno boolean,
	varsym character varying(255),
	idmeny integer,
	iduziv integer,
	idtypdokl integer,
	novy boolean,
	uroven integer,
	stavk character varying(255)
);

ALTER TYPE public.vazbadokladu OWNER TO %firmaRole%;


CREATE OR REPLACE FUNCTION findvazbydokladu(_iddokl integer, _modul character varying)
  RETURNS SETOF vazbadokladu AS
$BODY$
declare
  zaznam Record;
  _uroven integer;
  _prechodVP boolean;    -- zda povolen prechod z PPV/OBV na PPP/OBP
begin
  _uroven = 1;
  _prechodVP = true;

  drop table if exists vazbydokladu;

  CREATE TEMPORARY TABLE vazbydokladu
   (idvazebnidoklad integer NOT NULL,
    datucto timestamp without time zone,
    datvyst timestamp without time zone,
    iddokl integer,
    kod character varying(255),
    modul character varying(255),
    modulk character varying(255),
    popis text,
    poznam text,
    sumcelkem double precision,
    sumcelkemmen double precision,
    typvazbyk character varying(255),
    storno boolean,
    varsym character varying(255),
    idmeny integer,
    iduziv integer,
    idtypdokl integer,
    novy boolean,
    uroven integer,
    stavk character varying(255),
    CONSTRAINT vazbydokladu_pkey PRIMARY KEY (idvazebnidoklad)
  ) WITH (OIDS=FALSE);

  perform findViceVazeb('vazbydokladu', _idDokl, _modul, 0, true);

  while (select count(*) from vazbydokladu where novy = true) > 0 LOOP
    if _prechodVP then
      select (count(*) = 0) into _prechodVP from vazbydokladu where modul in ('OBP', 'PPP') and novy = true;
    end if;

    for zaznam in (select * from vazbydokladu where novy = true)
    LOOP
      perform findViceVazeb('vazbydokladu', zaznam.idDokl, zaznam.modul, _uroven, _prechodVP);

      update vazbydokladu set novy = false where idvazebnidoklad = zaznam.idvazebnidoklad;
    end loop;

    _uroven = _uroven + 1;
  end loop;

  update vazbydokladu as V set modulK = modulK ||
    (case when (select typPohybuK from dDoklSklad where idDoklSklad = V.idDokl) = 'typPohybu.prijem' then 'PRI' else 'VYD' end)
    where V.modul = 'SKL';

  return query SELECT * FROM vazbydokladu;
end;
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100
  ROWS 1000;

ALTER FUNCTION findvazbydokladu(integer, character varying) OWNER TO %firmaRole%;


CREATE OR REPLACE FUNCTION findvicevazeb(_inserttab character varying, _iddokl integer, _modul character varying, _uroven integer, _prechodvp boolean)
  RETURNS void AS
$BODY$
declare
  tabulka varchar(20);
  poleStav varchar(20);
  dotaz varchar;
  prechodPom varchar;
begin
  tabulka = getdoklnamepostfixbymodul(_modul);
  prechodPom = '';

  if (_uroven = 0) then
    if (tabulka = 'Fak') then
      poleStav = 'stavUhrK';
    else
      poleStav = 'stavUzivK';
    end if;

    dotaz =
      'select 0 as idVazby, null as typVazbyK, false as storno, D.idDokl' || tabulka || ' as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.' || poleStav || ' as stavK
        from dDokl' || tabulka || ' as D where D.idDokl' || tabulka || ' = ' || _idDokl || ' and D.modul = ''' || _modul || '''';
  else

  if (tabulka = 'Fak') then
    dotaz =
      'select V.idVazby, V.typVazbyK, V.storno, D.idDoklInt as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklInt as D on V.idTabB=D.idDoklInt and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and V.typVazbyK in (''typVazbyDokl.uhrada'', ''typVazbyDokl.uhradaKR'',
            ''typVazbyDokl.uhradaZB'', ''typVazbyDokl.preceneni'', ''typVazbyDokl.vazbaZDD'', ''typVazbyDokl.uhradaZALOHY'')
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklSklad as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklSklad as D on V.idTabB=D.idDoklSklad and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and V.typVazbyK = ''typVazbyDokl.hlavaSkl''
      union
      select min(V.idVazby) as idVazby, V.typVazbyK, V.storno, D.idDoklFak as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUhrK as stavK
        from dVazebTab as V left outer join dDoklFak as D on V.idTabB=D.idDoklFak and V.modulB=D.modul
        where V.idTabA in (select idPolFak from dPolFak where idDoklFak=' || _idDokl || ') and V.modulA=''' || _modul || ''' and
          V.typVazbyK in (''typVazbyDokl.odpocetZALOHY'', ''typVazbyDokl.odpocetZDD'')
        group by V.typVazbyK, V.storno, D.idDoklFak, D.modul, D.kod, D.varSym, D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavuhrK
      union
      select min(V.idVazby) as idVazby, V.typVazbyK, V.storno, D.idDoklFak as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUhrK as stavK
        from dVazebTab as V left outer join dDoklFak as D on D.idDoklFak=
                (select idDoklFak from dPolFak where idPolFak = V.idTabA) and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and V.typVazbyK in (''typVazbyDokl.odpocetZALOHY'', ''typVazbyDokl.odpocetZDD'')
        group by V.typVazbyK, V.storno, D.idDoklFak, D.modul, D.kod, D.varSym, D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUhrK
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklObch as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklObch as D on V.idTabA=D.idDoklObch and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and V.typVazbyK in (''typVazbyDokl.obchod_faktura_hla'', ''typVazbyDokl.obchod_zaloha_hla'')';
  else if (tabulka = 'Int') then
    dotaz =
      'select V.idVazby, V.typVazbyK, V.storno, D.idDoklFak as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUhrK as stavK
        from dVazebTab as V left outer join dDoklFak as D on V.idTabA=D.idDoklFak and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and V.typVazbyK in (''typVazbyDokl.uhrada'', ''typVazbyDokl.uhradaKR'',
            ''typVazbyDokl.uhradaZB'', ''typVazbyDokl.preceneni'', ''typVazbyDokl.vazbaZDD'', ''typVazbyDokl.uhradaZALOHY'')
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklSklad as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklSklad as D on V.idTabB=D.idDoklSklad and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and V.typVazbyK in (''typVazbyDokl.hlavaSkl'')
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklInt as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklInt as D on V.idTabA=D.idDoklInt and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and V.typVazbyK in (''typVazbyDokl.KR'', ''typVazbyDokl.ZB'')
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklInt as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklInt as D on V.idTabB=D.idDoklInt and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and V.typVazbyK in (''typVazbyDokl.KR'', ''typVazbyDokl.ZB'')';
  else if (tabulka = 'Sklad') then
    dotaz =
      'select V.idVazby, V.typVazbyK, V.storno, D.idDoklFak as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUhrK as stavK
        from dVazebTab as V left outer join dDoklFak as D on V.idTabA=D.idDoklFak and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and
          V.modulA in (''FAV'',''FAP'',''PHL'',''ZAV'') and V.typVazbyK = ''typVazbyDokl.hlavaSkl''
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklInt as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklInt as D on V.idTabA=D.idDoklInt and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and
          V.modulA in (''BAN'',''POK'',''INT'') and V.typVazbyK = ''typVazbyDokl.hlavaSkl''
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklSklad as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklSklad as D on V.idTabA=D.idDoklSklad and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and
          V.modulA in (''SKL'') and V.typVazbyK = ''typVazbyDokl.hlavaSklKus''
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklSklad as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklSklad as D on V.idTabB=D.idDoklSklad and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and
          V.modulB in (''SKL'') and V.typVazbyK = ''typVazbyDokl.hlavaSklKus''
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklSklad as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklSklad as D on V.idTabA=D.idDoklSklad and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and
          V.modulA in (''SKL'') and V.typVazbyK = ''typVazbyDokl.hlavaSklPrevod''
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklSklad as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklSklad as D on V.idTabB=D.idDoklSklad and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and
          V.modulB in (''SKL'') and V.typVazbyK = ''typVazbyDokl.hlavaSklPrevod''
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklObch as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklObch as D on V.idTabA=D.idDoklObch and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and V.typVazbyK = ''typVazbyDokl.obchod_sklad_hla''';
  else if (tabulka = 'Obch') then
    if (_prechodVP = false and _modul in ('PPV', 'OBV')) then
      prechodPom = ' and D.modul in (''PPV'', ''NAP'', ''OBV'')';
    end if;

    dotaz =
      'select V.idVazby, V.typVazbyK, V.storno, D.idDoklObch as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklObch as D on V.idTabA=D.idDoklObch and V.modulA=D.modul
        where V.idTabB=' || _idDokl || ' and V.modulB=''' || _modul || ''' and V.typVazbyK = ''typVazbyDokl.obchod_obchod_hla''' || prechodPom || '
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklObch as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklObch as D on V.idTabB=D.idDoklObch and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and V.typVazbyK = ''typVazbyDokl.obchod_obchod_hla''' || prechodPom || '
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklFak as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUhrK as stavK
        from dVazebTab as V left outer join dDoklFak as D on V.idTabB=D.idDoklFak and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and V.typVazbyK in (''typVazbyDokl.obchod_faktura_hla'', ''typVazbyDokl.obchod_zaloha_hla'')
      union
      select V.idVazby, V.typVazbyK, V.storno, D.idDoklSklad as idDokl, D.modul, ''modulUcetni.''||D.Modul as ModulK, D.kod, D.varSym,
        D.datVyst, D.datUcto, D.sumCelkem, D.sumCelkemMen, D.popis, D.poznam, D.idTypDokl, D.idMeny, D.idUziv, D.stavUzivK as stavK
        from dVazebTab as V left outer join dDoklSklad as D on V.idTabB=D.idDoklSklad and V.modulB=D.modul
        where V.idTabA=' || _idDokl || ' and V.modulA=''' || _modul || ''' and V.typVazbyK = ''typVazbyDokl.obchod_sklad_hla''';
  else
    raise exception 'findVazbyDokladu(): Neznámá tabulka % pro modul %', tabulka, _modul;
  end if;
  end if;
  end if;
  end if;

  end if;

  execute 'insert into ' || _insertTab || ' (idvazebnidoklad, typVazbyK, storno, idDokl, modul, modulk, kod, varsym, datvyst, datucto, sumcelkem,
  sumcelkemmen, popis, poznam, idtypdokl,idmeny, iduziv, stavk, uroven, novy) select *, ' || _uroven || ', true from ('
     || dotaz || ') as UN where (select count(*) from ' || _insertTab || ' as TV where
     (TV.idDokl = UN.idDokl and TV.modul = UN.modul) or UN.idVazby = TV.idvazebnidoklad) = 0';
end;
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;

ALTER FUNCTION findvicevazeb(character varying, integer, character varying, integer, boolean) OWNER TO %firmaRole%;


-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 283, 't');
