---------------------------------------------------------------------
-- Bug 18953 – [WinStrom] Přehledy zaměstnanců
---------------------------------------------------------------------

-- pridani sloupce pro uvazek hodin denne
ALTER TABLE ppracpom ADD COLUMN uvazhoddenne numeric(6,2) DEFAULT 0.0;
-- nakopirovani hodin - doted byli v uvazhodtydne
UPDATE ppracpom SET uvazhoddenne = uvazhodtydne;

-- uprava triggeru generujici smeny pro pracovni pomer
CREATE OR REPLACE FUNCTION pgeneratesmenyforpracpom(_idpracpom integer, _rok integer, _mesic integer)
  RETURNS void AS $$
declare
  _pocatMes date;
  _pracpom record;
  _idsmeny integer;
  _den varchar;
  _mesicS varchar;
  _aktDatum date;
  _denTyden integer;
  _vysledek text;
  _smena integer;
  _smenaSvatek integer;
  _pocatSmeny integer;
  _konecSmeny integer;
  _svatku integer;
begin
  _pocatMes = date(_rok || '-' || _mesic || '-01');
  _mesicS = _mesic;
  if (length(_mesicS) < 2) then
    _mesicS = '0' || _mesicS;
  end if;
  
  select * into _pracpom from ppracpom where idpracpomhlav = _idpracpom and 
    (platiOd is null or platiOd <= _pocatMes) and (platiDo is null or platiDo >= _pocatMes) order by platiOd limit 1;
  
  if (_pracpom is null) then
    return;
  end if;
  
  select idsmeny, planovane into _idsmeny, _vysledek from psmeny where idpracpom = _idpracpom and rok = _rok and mesic = _mesic;
  
  if (_vysledek is null) then
    _vysledek = '';
  end if;
  
  if (_pracpom.pracrozvrhk = 'pracRozvrh.pravidelny') then
    _aktDatum = _pocatMes;
    _smena = 1;
    _smenaSvatek = 1;
    _vysledek = '';
    while extract (month from _aktDatum) = _mesic loop
      _denTyden = extract (dow from _aktDatum);
      _den = extract (day from _aktDatum);
      if (length(_den) < 2) then
        _den = '0' || _den;
      end if;
      if _denTyden = 0 then _denTyden = 7; end if;       -- nedele je 7y den
      
      if (_denTyden <= _pracpom.uvazDnuTydne) then
        select count(*) into _svatku from pmzdyparam where klic = 'svatek' and 
            ((hodnota = _rok || '-' || _mesicS || '-' || _den) or (hodnota = 'XXXX-' || _mesicS || '-' || _den));
      
        if (length(_vysledek) > 0) then _vysledek = _vysledek || ';'; end if;  -- pripojime strednik mezi smeny
        
        _pocatSmeny = (extract (day from _aktDatum) - 1) * 1440 + cast((_pracpom.zacPracDoby * 60) as integer);
        _konecSmeny = _pocatSmeny + cast((60 * _pracpom.uvazHodDenne) as integer) - 1;
        
        if (_svatku = 0) then
          _vysledek = _vysledek || _smena;
          _smena = _smena + 1;
        else  
          _vysledek = _vysledek || 's' || _smenaSvatek;
          _smenaSvatek = _smenaSvatek + 1;
        end if;
        _vysledek = _vysledek || ':' || _pocatSmeny || ':' || _konecSmeny;
      end if;
      
      _aktDatum = _aktDatum + interval '1 day';
    end loop;
  
  end if;
  
  if (_idsmeny is null) then
    insert into psmeny (idosoba, idpracpom, rok, mesic, planovane)
      values (_pracpom.idosoba, _idpracpom, _rok, _mesic, _vysledek);
  else
    update psmeny set planovane = _vysledek where idpracpom = _idpracpom and rok = _rok and mesic = _mesic;
  end if;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pgeneratesmenyforpracpom(integer, integer, integer) OWNER TO %firmaRole%;

-- spocteni uvazku hodin tydne
UPDATE ppracpom SET uvazhodtydne = coalesce(uvazhoddenne, 0.0) * coalesce(uvazdnutydne, 0.0);

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 288, 't');

