-----------------------------------------------------------------------------------------------------
-- Bug 20743 – [WinStrom] Nelze zmenit polozku ceniku v polozce faktury, pokud byla s vyrobnim cislem
-----------------------------------------------------------------------------------------------------

-- Function: svyrobnicisloinsertupdate()
-- DROP FUNCTION svyrobnicisloinsertupdate();
CREATE OR REPLACE FUNCTION svyrobnicisloinsertupdate()
  RETURNS trigger AS
$BODY$ 
declare 
  _idPolSklad integer; 
begin 
  --if(NEW.idPolSkladPrijem is null) then 
    if(tg_op = 'INSERT') then 
      if(NEW.idPolFakPrijem is not null) then  
        select findParovanyPolSklad(NEW.idPolFakPrijem, 'FAP') into _idPolSklad; 
        if(_idPolSklad is null) then 
          select findParovanyPolSklad(NEW.idPolFakPrijem, 'FAV') into _idPolSklad;  
        end if; 
      elsif(NEW.idPolIntPrijem is not null) then 
        select findParovanyPolSklad(NEW.idPolIntPrijem, 'POK') into _idPolSklad; 
      end if; 
      if(_idPolSklad is not null) then 
        NEW.idPolSkladPrijem = _idPolSklad; 
      end if; 
    elsif(tg_op = 'UPDATE') then 
      if(NEW.idPolFakPrijem is not null) then  
        select findParovanyPolSklad(NEW.idPolFakPrijem, 'FAP') into _idPolSklad; 
        if(_idPolSklad is null) then 
          select findParovanyPolSklad(NEW.idPolFakPrijem, 'FAV') into _idPolSklad;  
        end if; 
      elsif(NEW.idPolIntPrijem is not null) then  
        select findParovanyPolSklad(NEW.idPolIntPrijem, 'POK') into _idPolSklad; 
      end if; 
      if(_idPolSklad is not null) then 
        NEW.idPolSkladPrijem = _idPolSklad; 
      end if; 
    end if; 
  --end if;  
  _idPolSklad = null;  
  if(NEW.idPolSkladVydej is null) then  
    if(tg_op = 'INSERT') then  
      if(NEW.idPolFakVydej is not null) then   
        select findParovanyPolSklad(NEW.idPolFakVydej, 'FAV') into _idPolSklad;  
        if(_idPolSklad is null) then 
          select findParovanyPolSklad(NEW.idPolFakVydej, 'FAP') into _idPolSklad;  
        end if;   
      elsif(NEW.idPolIntVydej is not null) then  
        select findParovanyPolSklad(NEW.idPolIntVydej, 'POK') into _idPolSklad;  
      end if;  
      if(_idPolSklad is not null) then  
        NEW.idPolSkladVydej = _idPolSklad;  
      end if;  
    elsif(tg_op = 'UPDATE') then  
      if((NEW.idPolFakVydej is not null and OLD.idPolFakVydej is null) or (NEW.idPolFakVydej <> OLD.idPolFakVydej)) then  
        select findParovanyPolSklad(NEW.idPolFakVydej, 'FAV') into _idPolSklad;  
        if(_idPolSklad is null) then 
          select findParovanyPolSklad(NEW.idPolFakVydej, 'FAP') into _idPolSklad;  
        end if;   
      elsif((NEW.idPolIntVydej is not null and OLD.idPolIntVydej is null) or (NEW.idPolIntVydej <> OLD.idPolIntVydej)) then  
        select findParovanyPolSklad(NEW.idPolIntVydej, 'POK') into _idPolSklad;  
      end if;  
      if(_idPolSklad is not null) then  
        NEW.idPolSkladVydej = _idPolSklad;  
      end if;  
    end if;  
  end if;  
 
  return NEW; 
end; 
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION svyrobnicisloinsertupdate() OWNER TO %firmaRole%;

-- Function: svyrobnicislocreatehlav()
-- DROP FUNCTION svyrobnicislocreatehlav();
CREATE OR REPLACE FUNCTION svyrobnicislocreatehlav()
  RETURNS trigger AS
$BODY$ 
declare 
  hlav record; 
begin 
  -- hlavicka neexistuje -> vytvorime ji 
  if (NEW.idvyrobnicislohlav is NULL) then 
    insert into svyrobnicislohlav(kod, idcenik) 
      values (NEW.kod, NEW.idcenik); 
    select currval('seq_svyrobnicislohlav') into NEW.idvyrobnicislohlav; 
  -- polozka se jiz vaze na hlavicku, pro jistotu zkontrolujeme, 
  -- ze mame stejny kod a idcenik 
  else 
    select * into hlav from svyrobnicislohlav h where h.idvyrobnicislohlav = NEW.idvyrobnicislohlav; 
 
    -- kod noveho pohybu se musi rovnat kodu na hlavicce 
    if (tg_op = 'INSERT' and NEW.kod != hlav.kod) then 
      raise exception 'Kod pohybu vyrobniho cisla % se neshoduje s kodem na hlavicce %.', NEW.kod, hlav.kod; 
    end if; 
 
    -- pouzivaji se 2 vnorene if, protoze postgresql pri vyhodnocovani vyhodnocuje 
    --vsechny logicke vyrazy a OLD pri insert neni nainicializovana 
 
    -- pri aktualizaci zkontrolujeme, ze kod pohybu je stejny jako kod na hlavicce 
    if (tg_op = 'UPDATE') then 
      if (OLD.kod != hlav.kod) then 
        raise exception 'Kod pohybu vyrobniho cisla % se neshoduje s kodem na hlavicce %.', OLD.kod, hlav.kod; 
      end if; 
 
      -- pri aktualizaci a prepsani kodu pohybu vyrobniho cisla - pozmenime kod i na hlavicce 
      if (OLD.kod != NEW.kod) then 
	update svyrobnicislohlav set kod = NEW.kod where idvyrobnicislohlav = NEW.idvyrobnicislohlav; 
      end if; 
    end if; 
 
    if (NEW.idcenik != hlav.idcenik) then 
      if (NEW.idpolskladvydej != null or NEW.idpolfakvydej != null or NEW.idpolintvydej != null) then
       raise exception 'Menite cenik % u jiz vydaneho vyrobniho cisla %', NEW.idcenik, NEW.idvyrobnicislo;
    end if;

    update svyrobnicislohlav set idcenik = NEW.idcenik where idvyrobnicislohlav = NEW.idvyrobnicislohlav;
    end if; 
  end if; 
 
  return NEW; 
end 
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION svyrobnicislocreatehlav() OWNER TO %firmaRole%;

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 390, 't');