--------------------------------------------------------------------------------
-- Bug 22498 – [WinStrom] 10 - Mzdy - Pri zmene stale mzdove slozky se zrusi datum vypoctu mzdy
--------------------------------------------------------------------------------

-- kdyz menime ucetni obdobi mazeme vsechy prebytecne ale pregenerovavame jen v menenem obdobi, jinde je to zbytecne
CREATE OR REPLACE FUNCTION pgeneratemzdslozforpracpom(_idpracpom integer, _iducetobd integer)
  RETURNS void AS $$
declare
  _od date;
  _do date;
  _odAkt date;
  rokod integer;
  rokdo integer;
  mesicod integer;
  mesicdo integer;
  rokOdAkt integer;
  mesicOdAkt integer;
  
  mesforod integer;
  mesfordo integer;
  aktrok integer;
  aktmesic integer;
  aktdatum date;
  _idOsoba integer;
begin
  select min(platioddata), max(platidodata) into _od, _do from nucetobdobi;
  rokod = date_part('year', _od);
  rokdo = date_part('year', _do);
  mesicod = date_part('month', _od);
  mesicdo = date_part('month', _do);
  
  if  (_idpracpom > -1) then        -- pokud delame jenom jeden pracovni pomer delame smeny i mimo obdobi
    select aktivniod, idosoba into _odAkt, _idOsoba from ppracpomhlav where idpracpomhlav = _idpracpom;
    rokOdAkt = date_part('year', _odAkt);
    mesicOdAkt = date_part('month', _odAkt);
    
    for aktrok in rokOdAkt..rokod loop
      mesforod = 1;
      mesfordo = 12;
      if (aktrok = rokOdAkt) then
        mesforod = mesicOdAkt;
      end if;  
      if (aktrok = rokod) then
        mesfordo = mesicod - 1;
      end if;
    
      -- a mesice
      for aktmesic in mesforod..mesfordo loop
        if (not pismzdyzamek(aktrok, aktmesic)) then
          -- smeny
          perform pgeneratesmenyforpracpom(_idpracpom, aktrok, aktmesic) where pcantriggerchangeslozku(aktrok, aktmesic, _idOsoba);
        end if;
      end loop;
    end loop;
  end if; 
  
  -- vymazeme nadbytecne
  delete from pmzdsloz where (rok < rokod or (rok = rokod and mesic < mesicod)) or (rok > rokdo or (rok = rokdo and mesic > mesicdo));
  delete from psmeny where (rok > rokdo or (rok = rokdo and mesic > mesicdo));
  
  -- pokud se meni ucetni obdobi generujeme jen v nem
  if (_iducetobd > -1) then
    select platioddata, platidodata into _od, _do from nucetobdobi where iducetobdobi = _iducetobd;
    if (_od is null) then   -- jsme zde protoze se obdobi smazalo, coz zatim sice neumime ale co kdyby nekdy
      return;               -- pak neni co generovat
    end if;
    
    rokod = date_part('year', _od);
    rokdo = date_part('year', _do);
    mesicod = date_part('month', _od);
    mesicdo = date_part('month', _do);
  end if;
  
  -- prochazime roky
  for aktrok in rokod..rokdo loop
    mesforod = 1;
    mesfordo = 12;
    if (aktrok = rokod) then
      mesforod = mesicod;
    end if;  
    if (aktrok = rokdo) then
      mesfordo = mesicdo;
    end if;
    
    -- a mesice
    for aktmesic in mesforod..mesfordo loop
      if (not pismzdyzamek(aktrok, aktmesic)) then
        aktdatum = date (aktrok || '-' || aktmesic || '-01');
      
        perform pgeneratemzdslozforpracpomandmesic(idpracpomhlav, aktrok, aktmesic) from ppracpomhlav where
          (_idpracpom = -1 or idpracpomhlav = _idpracpom) and (aktivnido is null or aktdatum <= aktivnido) and 
          (aktivniod is null or date_part('year', aktivniod) < aktrok or (date_part('year', aktivniod) = aktrok and date_part('month', aktivniod) <= aktmesic));
      end if;
    end loop;
  end loop;
end; 
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pgeneratemzdslozforpracpom(integer, integer) OWNER TO %firmaRole%;

-- pro zachovani zpetne kompatibility - buh vi kde se to vsude vola
CREATE OR REPLACE FUNCTION pgeneratemzdslozforpracpom(_idpracpom integer)
  RETURNS void AS $$
begin
  perform pgeneratemzdslozforpracpom(_idpracpom, -1);
end; 
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pgeneratemzdslozforpracpom(integer) OWNER TO %firmaRole%;

-- pri zmene ucetniho obdobi upravujeme mzdy jenom nad nim
CREATE OR REPLACE FUNCTION nucetobdobiupdatemzdsloz() RETURNS trigger AS $$
declare
  ZAZNAM record;
begin
  if (tg_op = 'DELETE') then
    ZAZNAM := OLD;
  else
    ZAZNAM := NEW;
  end if;
  
  if (tg_op = 'UPDATE') then
    if (NEW.platioddata <> OLD.platioddata or NEW.platidodata <> OLD.platidodata) then
      perform pgeneratemzdslozforpracpom(-1, NEW.iducetobdobi);
    end if;
  else
    perform pgeneratemzdslozforpracpom(-1, ZAZNAM.iducetobdobi);
  end if;
  
  return ZAZNAM;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.nucetobdobiupdatemzdsloz() OWNER TO %firmaRole%;


--------------------------------------------------------------------------------
-- zmena ulozenych procedur prenasejicich zmeny, aby je prenaseli jen kdyz nejake jsou
--------------------------------------------------------------------------------

-- generace smen - tahle uprava by opravila problem s ucetnima obdobima resenyma vyse,
-- ale stejne bylo dobry to zoptimalizovat
CREATE OR REPLACE FUNCTION pgeneratesmenyforpracpom(_idpracpom integer, _rok integer, _mesic integer)
  RETURNS void AS $$
declare
  _pocatMes date;
  _pracpom record;
  _idsmeny integer;
  _den varchar;
  _mesicS varchar;
  _aktDatum date;
  _denTyden integer;
  _vysledek text;
  _smena integer;
  _smenaSvatek integer;
  _pocatSmeny integer;
  _konecSmeny integer;
  _svatku integer;
begin
  _pocatMes = date(_rok || '-' || _mesic || '-01');
  _mesicS = _mesic;
  if (length(_mesicS) < 2) then
    _mesicS = '0' || _mesicS;
  end if;
  
  select * into _pracpom from ppracpom where idpracpomhlav = _idpracpom and 
    (platiOd is null or platiOd <= _pocatMes) and (platiDo is null or platiDo >= _pocatMes) order by platiOd limit 1;
  
  if (_pracpom is null) then
    return;
  end if;
  
  select idsmeny, planovane into _idsmeny, _vysledek from psmeny where idpracpom = _idpracpom and rok = _rok and mesic = _mesic;
  
  if (_vysledek is null) then
    _vysledek = '';
  end if;
  
  if (_pracpom.pracrozvrhk = 'pracRozvrh.pravidelny') then
    _aktDatum = _pocatMes;
    _smena = 1;
    _smenaSvatek = 1;
    _vysledek = '';
    while extract (month from _aktDatum) = _mesic loop
      _denTyden = extract (dow from _aktDatum);
      _den = extract (day from _aktDatum);
      if (length(_den) < 2) then
        _den = '0' || _den;
      end if;
      if _denTyden = 0 then _denTyden = 7; end if;       -- nedele je 7y den
      
      if (_denTyden <= _pracpom.uvazDnuTydne) then
        select count(*) into _svatku from pmzdyparam where klic = 'svatek' and 
            ((hodnota = _rok || '-' || _mesicS || '-' || _den) or (hodnota = 'XXXX-' || _mesicS || '-' || _den));
      
        if (length(_vysledek) > 0) then _vysledek = _vysledek || ';'; end if;  -- pripojime strednik mezi smeny
        
        _pocatSmeny = (extract (day from _aktDatum) - 1) * 1440 + cast((_pracpom.zacPracDoby * 60) as integer);
        _konecSmeny = _pocatSmeny + cast((60 * _pracpom.uvazHodDenne) as integer) - 1;
        
        if (_svatku = 0) then
          _vysledek = _vysledek || _smena;
          _smena = _smena + 1;
        else  
          _vysledek = _vysledek || 's' || _smenaSvatek;
          _smenaSvatek = _smenaSvatek + 1;
        end if;
        _vysledek = _vysledek || ':' || _pocatSmeny || ':' || _konecSmeny;
      end if;
      
      _aktDatum = _aktDatum + interval '1 day';
    end loop;
  
  end if;
  
  if (_idsmeny is null) then
    insert into psmeny (idosoba, idpracpom, rok, mesic, planovane)
      values (_pracpom.idosoba, _idpracpom, _rok, _mesic, _vysledek);
  else
    update psmeny set planovane = _vysledek where idpracpom = _idpracpom and rok = _rok and mesic = _mesic
      and not comparevarchar(planovane, _vysledek);
  end if;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pgeneratesmenyforpracpom(integer, integer, integer) OWNER TO %firmaRole%;

-- prenos dat z ciselniku
CREATE OR REPLACE FUNCTION pupdatemzdslozfromcis(_idMzdSloz integer, _idCis integer)
  RETURNS void AS $$
declare
  C record;
begin
  select * into C from pcismzdsloz where idcismzdsloz = _idCis;
  
  if (C.idcismzdsloz is not null) then
    update pmzdsloz set idcismzdsloz = _idCis, kod = C.kod, nazev = C.nazev, typslozkyk = C.typslozkyk, skupslozkyk = C.skupslozkyk, cisrad = C.cisrad, pracovni = C.pracovni,
      dnyPrac = C.dnyPrac, dnyKal = C.dnyKal, dnySvatek = C.dnySvatek, hodiny = C.hodiny, castkaHod = C.castkaHod, castkaDen = C.castkaDen, procMzd = C.procMzd, 
      zaklMzd = C.zaklMzd, zaklJeKracen = C.zaklJeKracen, castMzd = C.castMzd, zmenaCastMzd = C.zmenaCastMzd, pocetMes = C.pocetMes, cisDoklNem = C.cisDoklNem, 
      prumNaDenNem = C.prumNaDenNem, prumNaHodNem = C.prumNaHodNem, doplatZdravK = C.doplatZdravK where idmzdsloz = _idMzdSloz and (
           idcismzdsloz <> _idCis or kod <> C.kod or nazev <> C.nazev or typslozkyk <> C.typslozkyk or skupslozkyk <> C.skupslozkyk or
           not compareid(cisrad, C.cisrad) or pracovni <> C.pracovni or dnyPrac <> C.dnyPrac or dnyKal <> C.dnyKal or dnySvatek <> C.dnySvatek or
           hodiny <> C.hodiny or castkaHod <> C.castkaHod or castkaDen <> C.castkaDen or procMzd <> C.procMzd or zaklMzd <> C.zaklMzd or
           zaklJeKracen <> C.zaklJeKracen or castMzd <> C.castMzd or zmenaCastMzd <> C.zmenaCastMzd or not compareId(pocetMes, C.pocetMes) or
           not compareid(cisDoklNem, C.cisDoklNem) or prumNaDenNem <> C.prumNaDenNem or prumNaHodNem <> C.prumNaHodNem or
           not comparevarchar(doplatZdravK, C.doplatZdravK));
  end if;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pupdatemzdslozfromcis(integer, integer) OWNER TO %firmaRole%;

-- prenos z odecitatelnych polozek
CREATE OR REPLACE FUNCTION pupdatemzdslozfromodecitpol(_idMzdSloz integer, _idOdecitPol integer)
  RETURNS void AS $$
declare
  O record;
begin
  select * into O from podecitpol where idodecitpol = _idOdecitPol;

  if (O.idodecitpol is not null) then
    -- pokud nesouhlasi ciselnik vyplnime ho
    perform pupdatemzdslozfromcis(idMzdSloz, O.idcismzdsloz) from pmzdsloz where idmzdsloz = _idMzdSloz and idcismzdsloz <> O.idcismzdsloz;
    -- pokud je treba prenest neco z odecitpol preneseme
    update pmzdsloz set idodecitpol = _idOdecitPol where idmzdsloz = _idMzdSloz and not compareid(idodecitpol, _idOdecitPol);
  end if;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pupdatemzdslozfromodecitpol(integer, integer) OWNER TO %firmaRole%;

-- prenos ze srazek
CREATE OR REPLACE FUNCTION pupdatemzdslozfromsrazka(_idMzdSloz integer, _idSrazka integer)
  RETURNS void AS $$
declare
  S record;
begin
  select * into S from psrazka where idsrazka = _idSrazka;

  if (S.idsrazka is not null) then
    -- pokud nesouhlasi ciselnik vyplnime ho
    perform pupdatemzdslozfromcis(idMzdSloz, S.idcismzdsloz) from pmzdsloz where idmzdsloz = _idMzdSloz and idcismzdsloz <> S.idcismzdsloz;
    -- preneseme data ze srazky
    update pmzdsloz set idsrazka = _idSrazka, kod = S.kod, nazev = S.nazev, poznam = S.poznam,
        procmzd = S.procmzd, skupslozkyk = S.skupslozkyk, typslozkyk = S.typslozkyk,
        castMzd = S.castka where idmzdsloz = _idMzdSloz and (
          not compareid(idsrazka, _idSrazka) or kod <> S.kod or nazev <> S.nazev or not comparevarchar(poznam, S.poznam) or
          procmzd <> S.procmzd or skupslozkyk <> S.skupslozkyk or typslozkyk <> S.typslozkyk or castMzd <> S.castka);
  end if;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pupdatemzdslozfromsrazka(integer, integer) OWNER TO %firmaRole%;

-- prenos ze stale mzdove slozky
CREATE OR REPLACE FUNCTION pupdatemzdslozfromstalasloz(_idMzdSloz integer, _idStalaSloz integer)
  RETURNS void AS $$
declare
  S record;
begin
  select * into S from pstalamzdsloz where idstalamzdsloz = _idStalaSloz;

  if (S.idstalamzdsloz is not null) then
    -- pokud nesouhlasi ciselnik vyplnime ho
    perform pupdatemzdslozfromcis(idMzdSloz, S.idcismzdsloz) from pmzdsloz where idmzdsloz = _idMzdSloz and idcismzdsloz <> S.idcismzdsloz;
    -- preneseme data ze stale mzdove slozky
    update pmzdsloz set idstalamzdsloz = _idStalaSloz,
        castkaden = S.castkaden, castkahod = S.castkahod, kod = S.kod, nazev = S.nazev, pocetmes = S.pocetmes, poznam = S.poznam,
        procmzd = S.procmzd, skupslozkyk = S.skupslozkyk, typslozkyk = S.typslozkyk, zakljekracen = S.zakljekracen, zaklmzd = S.zaklmzd,
        castmzd = S.castmzd, dnykal = S.dnykal, dnyprac = S.dnyprac, dnysvatek = S.dnysvatek, hodiny = S.hodiny, hodinysvatek = S.hodinysvatek,
        prumnadennem = S.prumnadennem, prumnahodnem = S.prumnahodnem,
        idstredisko = S.idstredisko, idzakazka = S.idzakazka
  -- NEW.podil, NEW.typpodilk,
      where idmzdsloz = _idMzdSloz and (not compareid(idstalamzdsloz, _idStalaSloz) or
        castkaHod <> S.castkaHod or castkaDen <> S.castkaDen or kod = S.kod or nazev = S.nazev or
        not compareId(pocetMes, S.pocetMes) or not comparevarchar(poznam, S.poznam) or procMzd <> S.procMzd or
        skupslozkyk <> S.skupslozkyk or typslozkyk <> S.typslozkyk or zaklMzd <> S.zaklMzd or zaklJeKracen <> S.zaklJeKracen or
        castMzd <> S.castMzd or dnykal <> S.dnykal or dnyprac <> S.dnyprac or dnysvatek <> S.dnysvatek or hodiny <> S.hodiny or
        hodinysvatek <> S.hodinysvatek or prumnadennem <> S.prumnadennem or prumnahodnem <> S.prumnahodnem or
        not compareid(idstredisko, S.idstredisko) or not compareid(idzakazka, S.idzakazka));
  end if;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pupdatemzdslozfromstalasloz(integer, integer) OWNER TO %firmaRole%;

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 455, 't', %appVersion%, clock_timestamp());
