---------------------------------------------------------------------------------------------
-- Bug 41807 - kombinace výdejky více kusů a dobropisu způsobuje problémy při přepočtu 
---------------------------------------------------------------------------------------------

-- funkce, která zavolá fifo výdej, ale naví - pokud se jedná o dobropis, provede zahrnutí dobropisu a až pak výdej 
CREATE OR REPLACE FUNCTION sfifoDobropis(s_idpoldobropis integer, s_idPolSklad integer, s_idCenik integer, s_idBspSkl integer, s_idKarty integer, s_mnozmj numeric(19,6), s_cenyRucne boolean)
  RETURNS void AS
$BODY$ 
declare 
  _odsunutaVydejka record;
  _pomocnaVydejka record;
  _sKartaDobropis record;
  _sKarta record;
  _shodneObdobi boolean;
   
  _suma numeric;
  _fifo record;
  _kusu numeric;

begin 
    select k.* into _sKartaDobropis from skarty k inner join dpolsklad ps on ps.idkarty = k.idkarty where ps.idpolsklad = s_idpoldobropis;
    select * into _sKarta from skarty where idKarty = s_idkarty;

    _shodneObdobi := (_sKarta.iducetobdobi = _sKartaDobropis.iducetobdobi);

    if(s_idpoldobropis is not null and s_idpoldobropis > 0 and _shodneObdobi) then 
      --_odsunuteVydejky = ARRAY(select idpolskladvydej from sfifovazby where idpolskladprijem = NEW.idPolDobropis); 
      --raise exception 'nevim zkusim sem dat nejakej text a uvidime %', _odsunuteVydejky; 
      CREATE TEMPORARY TABLE tmp_odsunutevydejky (  
         idpolskladvydej integer, 
         idvyrobnicislo integer, 
         kusu numeric(19,6) 
      ) WITH (OIDS=TRUE) ON COMMIT DROP;  

      -- temporary tabulka na idčka fifovazeb, které chceme taky smazat
      CREATE TEMPORARY TABLE tmp_fifo (  
         idFifo integer
      ) WITH (OIDS=TRUE) ON COMMIT DROP;

     for _fifo in (select * from sfifovazby where idpolskladvydej 
            in (select idpolskladvydej from sfifovazby where idpolskladprijem = s_idpoldobropis) 
            and idpolskladprijem <> s_idpoldobropis) loop 
        insert into tmp_fifo(idFifo) values ( _fifo.idfifovazby);  
      end loop; 

      for _odsunutaVydejka in (select * from sfifovazby where idpolskladprijem = s_idpoldobropis) loop 
        -- při opětovném výdeji odsunutých výdejek budeme chtít vydávat tolik kusů, na kolik je celá výdejka 
        -- (a ne jen jeden z jejích záznamů v sfifovazby)
        select sum (kusu) into _suma from sfifovazby where idfifovazby in (select idFifo from tmp_fifo) ;

        select sum(mnozMj) into _kusu from dpolsklad where idpolsklad = _odsunutaVydejka.idPolSkladVydej ;
        insert into tmp_odsunutevydejky(idpolskladvydej, idvyrobnicislo,kusu) 
          values (_odsunutaVydejka.idpolskladvydej, _odsunutaVydejka.idvyrobnicislo, _kusu); 
      end loop; 

      delete from sfifovazby where idpolskladprijem = s_idpoldobropis;       
    end if; 
     
    execute sFifoVydej(s_idPolSklad, s_idCenik, s_idBspSkl, s_idKarty, s_mnozmj, s_cenyRucne, not _shodneObdobi); 
 
    if(s_idpoldobropis is not null and s_idpoldobropis > 0 and _shodneObdobi) then 

      delete from sfifovazby where idfifovazby in (select idFifo from tmp_fifo) ;

      for _odsunutaVydejka in (select * from tmp_odsunutevydejky) loop 
        select * into _pomocnaVydejka from dpolsklad where idpolsklad = _odsunutaVydejka.idpolskladvydej; 
        execute sFifoVydej(_pomocnaVydejka.idPolSklad, _pomocnaVydejka.idCenik, _pomocnaVydejka.idBspSkl, _pomocnaVydejka.idKarty, _odsunutaVydejka.kusu, _pomocnaVydejka.cenyRucne);  
      end loop; 
      drop table tmp_odsunutevydejky;
      drop table tmp_fifo; 
    end if;
    
end; 
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION sfifoDobropis(integer, integer, integer, integer, integer, numeric(19,6), boolean)
  OWNER TO %firmaRole%;     

CREATE OR REPLACE FUNCTION sfifovydej(
    idvydej integer,
    idcenikvydej integer,
    idskladvydej integer,
    idkartyvydej integer,
    vyd numeric,
    _cenyrucne boolean)
  RETURNS void AS
$BODY$          
	
begin   
	execute sfifovydej(idvydej,idcenikvydej,idskladvydej,idkartyvydej, vyd,_cenyrucne, false);    
end;     
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION sfifovydej(integer, integer, integer, integer, numeric, boolean)
  OWNER TO %firmaRole%;


-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 899, 't', %appVersion%, clock_timestamp());