<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:rsp="http://www.stormware.cz/schema/version_2/response.xsd" 
xmlns:rdc="http://www.stormware.cz/schema/version_2/documentresponse.xsd" 
xmlns:typ="http://www.stormware.cz/schema/version_2/type.xsd" 
xmlns:dat="http://www.stormware.cz/schema/version_2/data.xsd"
xmlns:lst="http://www.stormware.cz/schema/version_2/list.xsd" 
xmlns:lStk="http://www.stormware.cz/schema/version_2/list_stock.xsd" 
xmlns:lAdb="http://www.stormware.cz/schema/version_2/list_addBook.xsd" 
xmlns:acu="http://www.stormware.cz/schema/version_2/accountingunit.xsd" 
xmlns:inv="http://www.stormware.cz/schema/version_2/invoice.xsd"
xmlns:vch="http://www.stormware.cz/schema/version_2/voucher.xsd"
xmlns:int="http://www.stormware.cz/schema/version_2/intDoc.xsd"
xmlns:stk="http://www.stormware.cz/schema/version_2/stock.xsd"
xmlns:ord="http://www.stormware.cz/schema/version_2/order.xsd"
xmlns:ofr="http://www.stormware.cz/schema/version_2/offer.xsd"
xmlns:enq="http://www.stormware.cz/schema/version_2/enquiry.xsd"
xmlns:vyd="http://www.stormware.cz/schema/version_2/vydejka.xsd"
xmlns:pri="http://www.stormware.cz/schema/version_2/prijemka.xsd"
xmlns:bal="http://www.stormware.cz/schema/version_2/balance.xsd"
xmlns:pre="http://www.stormware.cz/schema/version_2/prevodka.xsd"
xmlns:vyr="http://www.stormware.cz/schema/version_2/vyroba.xsd"
xmlns:pro="http://www.stormware.cz/schema/version_2/prodejka.xsd"
xmlns:con="http://www.stormware.cz/schema/version_2/contract.xsd"
xmlns:adb="http://www.stormware.cz/schema/version_2/addressbook.xsd"
xmlns:prm="http://www.stormware.cz/schema/version_2/parameter.xsd"
xmlns:lCon="http://www.stormware.cz/schema/version_2/list_contract.xsd"
xmlns:ctg="http://www.stormware.cz/schema/version_2/category.xsd"
xmlns:ipm="http://www.stormware.cz/schema/version_2/intParam.xsd"
xmlns:str="http://www.stormware.cz/schema/version_2/storage.xsd"
xmlns:java="http://xml.apache.org/xalan/java" exclude-result-prefixes="java">
    
	<xsl:output method="xml" encoding="utf-8" />
	
	
	<!-- 
  flexibee2xml-cli.exe -x ucet-pohoda.xml -t ucet-in.xslt -o ucet.xml -p year=2018
   -->

    <xsl:variable name="yearParam"><xsl:value-of select="java:flexibee.Tool.params('year')"/></xsl:variable>
    <xsl:variable name="yearExtIdPrefix"><xsl:value-of select="$yearParam"/><xsl:if test="$yearParam">-</xsl:if></xsl:variable>

	<xsl:template match="/">
	    <winstrom version="1.0" source="pohoda">
			  <xsl:apply-templates/>
	    </winstrom>	
	</xsl:template>

	<xsl:template match="dat:dataPackItem">
		  <xsl:apply-templates select="inv:invoice"/>
	</xsl:template>
	
	<xsl:template match="lst:listInvoice">
		  <xsl:apply-templates select="lst:invoice"/>
    </xsl:template>


    <xsl:template name="adresarId">
        <xsl:choose>
            <xsl:when test="typ:id">ext:POHODA-ADR:<xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="typ:id"/></xsl:when>
            <xsl:when test="normalize-space(typ:address/typ:ico) != ''">[in:<xsl:value-of select="typ:address/typ:ico"/>]</xsl:when>
            <xsl:when test="normalize-space(typ:address/typ:dic) != ''">[vatid:<xsl:value-of select="typ:address/typ:dic"/>]</xsl:when>
            <xsl:when test="normalize-space(concat(typ:address/typ:company, typ:address/typ:name)) != ''">ext:<xsl:value-of select="substring(concat('POHODA-ADR:', (typ:address/typ:company|typ:address/typ:name)[1], ',', typ:address/typ:street, ',', typ:address/typ:city, ',', typ:address/typ:zip), 0, 127)"/></xsl:when>
        </xsl:choose>
    </xsl:template>
  
    <xsl:template name="nazevFirmy">
        <xsl:value-of select="(typ:company|typ:name)[1]"/>
    </xsl:template>
  
    <xsl:template name="adresaSpolecna">
        <ulice><xsl:value-of select="typ:street"/></ulice>
        <mesto><xsl:value-of select="typ:city"/></mesto>
        <psc><xsl:value-of select="typ:zip"/></psc>
        <ic><xsl:value-of select="typ:ico"/></ic>
        <dic><xsl:value-of select="typ:dic"/></dic>
    </xsl:template>
  
    <xsl:template match="typ:address">
        <nazFirmy><xsl:call-template name="nazevFirmy"/></nazFirmy>
        <xsl:call-template name="adresaSpolecna"/>
    </xsl:template>
  
    <xsl:template match="typ:address" mode="create">
        <nazev><xsl:call-template name="nazevFirmy"/></nazev>
        <xsl:call-template name="adresaSpolecna"/>
        <skupFir if-not-found="null">code:ODBĚRATEL-STANDARD</skupFir>
    </xsl:template>
  
    <xsl:template match="inv:partnerIdentity" mode="create">
        <xsl:if test="normalize-space(concat(typ:address/typ:company, typ:address/typ:name)) != ''">
            <adresar update="ignore">
                <id><xsl:call-template name="adresarId"/></id>
                <xsl:apply-templates select="typ:address" mode="create"/>
            </adresar>
        </xsl:if>
    </xsl:template>
  
    <xsl:template match="inv:partnerIdentity">
        <firma if-not-found="null"><xsl:call-template name="adresarId"/></firma>
        <xsl:apply-templates select="typ:address"/>
    </xsl:template>

    <xsl:template name="bankovniUcetId">
        <xsl:choose>
            <xsl:when test="typ:id">ext:POHODA-BANSPOJ:<xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="typ:id"/></xsl:when>
            <xsl:when test="typ:ids">code:<xsl:value-of select="typ:ids"/></xsl:when>
            <xsl:when test="typ:accountNo">ext:POHODA-BANSPOJ:ACCNO-<xsl:value-of select="typ:accountNo"/>/<xsl:value-of select="typ:bankCode"/></xsl:when>
        </xsl:choose>
    </xsl:template>
  
    <xsl:template match="inv:account" mode="create">
        <bankovni-ucet update="ignore">
            <id><xsl:call-template name="bankovniUcetId"/></id>
            <nazev>
                <xsl:choose>
                    <xsl:when test="typ:ids"><xsl:value-of select="typ:ids"/></xsl:when>
                    <xsl:when test="typ:id"><xsl:value-of select="typ:id"/></xsl:when>
                    <xsl:otherwise>
                    <xsl:value-of select="typ:accountNo"/>/<xsl:value-of select="typ:bankCode"/>
                    </xsl:otherwise>
                </xsl:choose>
            </nazev>
            <xsl:if test="typ:accountNo">
                <buc><xsl:value-of select="typ:accountNo"/></buc>
            </xsl:if>
            <xsl:if test="typ:bankCode">
                <smerKod if-not-found="create">code:<xsl:value-of select="typ:bankCode"/></smerKod>
            </xsl:if>
        </bankovni-ucet>
    </xsl:template>

    <xsl:template match="inv:account">
        <bankovniUcet if-not-found="null"><xsl:call-template name="bankovniUcetId"/></bankovniUcet>
    </xsl:template>

    <xsl:template match="typ:paymentType">
        <formaUhradyCis if-not-found="null">code:<xsl:choose>
                <xsl:when test=".='draft'">PREVOD</xsl:when>
                <xsl:when test=".='cash'">HOTOVE</xsl:when>
                <xsl:when test=".='postal'">SLOZENKA</xsl:when>
                <xsl:when test=".='delivery'">DOBIRKA</xsl:when>
                <xsl:when test=".='creditcard'">KARTA</xsl:when>
                <xsl:when test=".='advance'">ZALOHA</xsl:when>
                <xsl:when test=".='encashment'">INKASO</xsl:when>
                <xsl:when test=".='cheque'">SEK</xsl:when>
                <xsl:when test=".='compensation'">ZAPOCET</xsl:when>
            </xsl:choose>
        </formaUhradyCis>
    </xsl:template>

    <xsl:template match="inv:invoiceType">
        <typDokl>code:<xsl:choose>
                <xsl:when test=".='issuedInvoice'">FAKTURA</xsl:when>
                <xsl:when test=".='issuedCreditNotice'">DOBROPIS</xsl:when>
                <xsl:when test=".='issuedAdvanceInvoice'">ZÁLOHA</xsl:when>
                <xsl:otherwise>PREVOD VF</xsl:otherwise>
            </xsl:choose>
        </typDokl>
    </xsl:template>


  <xsl:template match="lst:invoice|inv:invoice">

    <!-- zakládáme číselníky -->

    <!-- adresar -->
    <xsl:apply-templates select="inv:invoiceHeader/inv:partnerIdentity" mode="create"/>
    <!-- bankovni-ucet -->
    <xsl:apply-templates select="inv:invoiceHeader/inv:account" mode="create"/>


	<!-- importujeme úhrady? -->
	
    <xsl:if test="inv:invoiceHeader/inv:liquidation/typ:amountHome != '' or java:flexibee.Tool.params('uhrazene') != 'false'">
    
    <xsl:if test="inv:invoiceHeader/inv:liquidation/typ:date != ''">
      <pokladna update="ignore">
        <id>code:<xsl:value-of select="java:flexibee.Tool.join('PREVOD',inv:invoiceSummary/inv:foreignCurrency/typ:currency/typ:ids,'-')"/></id>
        <kod><xsl:value-of select="java:flexibee.Tool.join('PREVOD',inv:invoiceSummary/inv:foreignCurrency/typ:currency/typ:ids,'-')"/></kod>
        <nazev>Migrace z pohody</nazev>
        <radaPrijem>code:POKLADNA+</radaPrijem>
        <radaVydej>code:POKLADNA-</radaVydej>
        
        <xsl:if test="inv:invoiceSummary/inv:foreignCurrency/typ:currency/typ:ids != ''">
          <mena>code:<xsl:value-of select="inv:invoiceSummary/inv:foreignCurrency/typ:currency/typ:ids"/></mena>
        </xsl:if>
      </pokladna>
    </xsl:if>
  
  
    <faktura-vydana>
		<xsl:if test="inv:invoiceHeader/inv:id">
      		<id>ext:POHODA-FV:<xsl:value-of select="substring(inv:invoiceHeader/inv:date,0,5)"/>-<xsl:value-of select="inv:invoiceHeader/inv:id"/></id>
        </xsl:if>

      <xsl:choose>
        <xsl:when test="java:flexibee.Tool.endsWith(inv:invoiceHeader/inv:date, '-01-01') and java:flexibee.Tool.endsWith(inv:invoiceHeader/inv:number/typ:numberRequested, java:flexibee.Tool.join('/',substring(java:flexibee.Tool.round(java:flexibee.Tool.params('year')-1,'0'),1,4),''))">
          <id>ext:POHODA-FV-KOD:<xsl:value-of select="substring(java:flexibee.Tool.round(java:flexibee.Tool.params('year')-1,'0'),1,4)"/>-<xsl:value-of select="java:flexibee.Tool.toUpper(substring(inv:invoiceHeader/inv:number/typ:numberRequested,-4,string-length(inv:invoiceHeader/inv:number/typ:numberRequested)))"/></id>
        </xsl:when>
        <xsl:otherwise>
          <id>ext:POHODA-FV-KOD:<xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="java:flexibee.Tool.toUpper(inv:invoiceHeader/inv:number/typ:numberRequested)"/></id>
        </xsl:otherwise>
      </xsl:choose>
      
      <!-- typDokl -->
      <xsl:apply-templates select="inv:invoiceHeader/inv:invoiceType"/>

      <kod><xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="java:flexibee.Tool.toUpper(inv:invoiceHeader/inv:number/typ:numberRequested)"/></kod>
      <varSym><xsl:value-of select="java:flexibee.Tool.toUpper(inv:invoiceHeader/inv:symVar)"/></varSym>
      <datVyst><xsl:value-of select="inv:invoiceHeader/inv:date"/></datVyst>
      <xsl:if test="inv:invoiceHeader/inv:dateTax">
          <duzpPuv><xsl:value-of select="inv:invoiceHeader/inv:dateTax"/></duzpPuv>
      </xsl:if>
      <xsl:if test="inv:invoiceHeader/inv:dateAccounting">
          <datUcto><xsl:value-of select="inv:invoiceHeader/inv:dateAccounting"/></datUcto>
      </xsl:if>
      <datSplat><xsl:value-of select="inv:invoiceHeader/inv:dateDue"/></datSplat>
      
      <!-- inv:accounting -->
      <!-- inv:classificationVAT -->
      
      <popis><xsl:value-of select="inv:invoiceHeader/inv:text"/></popis>
      
      <!-- firma -->
      <xsl:apply-templates select="inv:invoiceHeader/inv:partnerIdentity"/>
      
      <!-- adresa + misto doruceni -->
      <!-- inv:myIdentity - udaje o me -->
      <cisObj><xsl:value-of select="inv:invoiceHeader/inv:numberOrder"/></cisObj>
      <!-- inv:dateOrder - datum objednavky -->
      <!-- inv:priceLevel - neco jako cenova uroven -->
  
      <!-- formaUhradyCis -->
      <xsl:apply-templates select="inv:invoiceHeader/inv:paymentType/typ:paymentType"/>
      <!-- bankovniUcet -->
      <xsl:apply-templates select="inv:invoiceHeader/inv:account"/>
      
	  <xsl:if test="inv:invoiceHeader/inv:symConst">
      	<konSym if-not-found="null">code:<xsl:value-of select="inv:invoiceHeader/inv:symConst"/></konSym>
  	  </xsl:if>
      
      <xsl:if test="inv:invoiceHeader/inv:paymentAccount/typ:accountNo != ''">
        <buc><xsl:value-of select="inv:invoiceHeader/inv:paymentAccount/typ:accountNo"/></buc>
      </xsl:if>
      <xsl:if test="inv:invoiceHeader/inv:paymentAccount/typ:bankCode != ''">
        <smerKod if-not-found="null">code:<xsl:value-of select="inv:invoiceHeader/inv:paymentAccount/typ:bankCode"/></smerKod>
      </xsl:if>
      
      <xsl:if test="inv:invoiceHeader/inv:centre/typ:id != ''">
        <stredisko if-not-found="null">ext:POHODA-STRED:<xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="inv:invoiceHeader/inv:centre/typ:id"/></stredisko>
      </xsl:if>
      <xsl:if test="inv:invoiceHeader/inv:activity/typ:id != ''">
        <cinnost if-not-found="null">ext:POHODA-CINNOST:<xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="inv:invoiceHeader/inv:activity/typ:id"/></cinnost>
      </xsl:if>
      <xsl:if test="inv:invoiceHeader/inv:contract/typ:id != ''">
        <zakazka if-not-found="null">ext:POHODA-ZAK:<xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="inv:invoiceHeader/inv:contract/typ:id"/></zakazka>
      </xsl:if>
      
<xsl:variable name="castkaDokl" select="0"/>

		<xsl:choose>
			<xsl:when test="inv:invoiceSummary">

  			<xsl:variable name="castkaDokl" select="java:flexibee.Tool.round(inv:invoiceSummary/inv:homeCurrency/typ:round/typ:priceRound + inv:invoiceSummary/inv:homeCurrency/typ:priceNone + inv:invoiceSummary/inv:homeCurrency/typ:priceLowSum + inv:invoiceSummary/inv:homeCurrency/typ:priceHighSum, '3')"/>
      
      <xsl:if test="inv:invoiceSummary/inv:foreignCurrency/typ:currency/typ:ids != ''">
        <mena>code:<xsl:value-of select="inv:invoiceSummary/inv:foreignCurrency/typ:currency/typ:ids"/></mena>
        <kurz><xsl:value-of select="inv:invoiceSummary/inv:foreignCurrency/typ:rate"/></kurz>
        <kurzMnozstvi><xsl:value-of select="inv:invoiceSummary/inv:foreignCurrency/typ:amount"/></kurzMnozstvi>
<!--        <sumCelkemMen><xsl:value-of select="inv:invoiceSummary/inv:foreignCurrency/typ:priceSum"/></sumCelkemMen>  -->
        
        <xsl:choose>
          <!-- bezpolozkova faktura -->
          <xsl:when test="count(inv:invoiceDetail/inv:invoiceItem) = 0">
            <sumCelkemMen><xsl:value-of select="java:flexibee.Tool.round((inv:invoiceSummary/inv:homeCurrency/typ:round/typ:priceRound + inv:invoiceSummary/inv:homeCurrency/typ:priceNone + inv:invoiceSummary/inv:homeCurrency/typ:priceLowSum + inv:invoiceSummary/inv:homeCurrency/typ:priceHighSum) * inv:invoiceSummary/inv:foreignCurrency/typ:amount div inv:invoiceSummary/inv:foreignCurrency/typ:rate, '3')"/></sumCelkemMen>
          </xsl:when>
          <!-- s polozkama -->
          <xsl:otherwise>
            <sumCelkemMen><xsl:value-of select="java:flexibee.Tool.round((sum(inv:invoiceDetail/inv:invoiceItem/inv:homeCurrency/typ:priceSum) + inv:invoiceSummary/inv:homeCurrency/typ:round/typ:priceRound) * inv:invoiceSummary/inv:foreignCurrency/typ:amount div inv:invoiceSummary/inv:foreignCurrency/typ:rate, '3')"/></sumCelkemMen>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:if>
	</xsl:when> <!-- inv:invoiceSummary -->
</xsl:choose>

      <generovatDorovnavaciPolozku>true</generovatDorovnavaciPolozku>


      <xsl:choose>
        <!-- bezpolozkova faktura -->
        <xsl:when test="count(inv:invoiceDetail/inv:invoiceItem) = 0">
		<xsl:if test="inv:invoiceSummary">
          <sumCelkem><xsl:value-of select="java:flexibee.Tool.round(inv:invoiceSummary/inv:homeCurrency/typ:round/typ:priceRound + inv:invoiceSummary/inv:homeCurrency/typ:priceNone + inv:invoiceSummary/inv:homeCurrency/typ:priceLowSum + inv:invoiceSummary/inv:homeCurrency/typ:priceHighSum, '3')"/></sumCelkem>

          <polozkyFaktury removeAll="true">
            <xsl:if test="inv:invoiceSummary/inv:homeCurrency/typ:priceNone != '' and inv:invoiceSummary/inv:homeCurrency/typ:priceNone != '0'">
              <faktura-vydana-polozka>
				<xsl:if test="inv:invoiceHeader/inv:id">
                	<id>ext:POHODA-FVPOLAUTOOSV:<xsl:value-of select="substring(inv:invoiceHeader/inv:date,0,5)"/>-<xsl:value-of select="inv:invoiceHeader/inv:id"/></id>
				</xsl:if>
                <typPolozkyK>typPolozky.ucetni</typPolozkyK>
                <typSzbDphK>typSzbDph.dphOsv</typSzbDphK>
                <sumCelkem><xsl:value-of select="inv:invoiceSummary/inv:homeCurrency/typ:priceNone"/></sumCelkem>
              </faktura-vydana-polozka>
            </xsl:if>
            <xsl:if test="inv:invoiceSummary/inv:homeCurrency/typ:priceLowSum != '' and inv:invoiceSummary/inv:homeCurrency/typ:priceLowSum != '0'">
              <faktura-vydana-polozka>
				<xsl:if test="inv:invoiceHeader/inv:id">
                	<id>ext:POHODA-FVPOLAUTOSNIZ:<xsl:value-of select="substring(inv:invoiceHeader/inv:date,0,5)"/>-<xsl:value-of select="inv:invoiceHeader/inv:id"/></id>
				</xsl:if>
                <typPolozkyK>typPolozky.ucetni</typPolozkyK>
                <typSzbDphK>typSzbDph.dphSniz</typSzbDphK>
                <sumZkl><xsl:value-of select="inv:invoiceSummary/inv:homeCurrency/typ:priceLow"/></sumZkl>
                <sumDph><xsl:value-of select="inv:invoiceSummary/inv:homeCurrency/typ:priceLowVAT"/></sumDph>
                <sumCelkem><xsl:value-of select="inv:invoiceSummary/inv:homeCurrency/typ:priceLowSum"/></sumCelkem>
              </faktura-vydana-polozka>
            </xsl:if>
            <xsl:if test="inv:invoiceSummary/inv:homeCurrency/typ:priceHighSum != '' and inv:invoiceSummary/inv:homeCurrency/typ:priceHighSum != '0'">
              <faktura-vydana-polozka>
				<xsl:if test="inv:invoiceHeader/inv:id">
                	<id>ext:POHODA-FVPOLAUTOZAKL:<xsl:value-of select="substring(inv:invoiceHeader/inv:date,0,5)"/>-<xsl:value-of select="inv:invoiceHeader/inv:id"/></id>
				</xsl:if>
                <typPolozkyK>typPolozky.ucetni</typPolozkyK>
                <typSzbDphK>typSzbDph.dphZakl</typSzbDphK>
                <sumZkl><xsl:value-of select="inv:invoiceSummary/inv:homeCurrency/typ:priceHigh"/></sumZkl>
                <sumDph><xsl:value-of select="inv:invoiceSummary/inv:homeCurrency/typ:priceHighVAT"/></sumDph>
                <sumCelkem><xsl:value-of select="inv:invoiceSummary/inv:homeCurrency/typ:priceHighSum"/></sumCelkem>
              </faktura-vydana-polozka>
            </xsl:if>
          </polozkyFaktury>

		</xsl:if> <!-- inv:invoiceSummary -->

        </xsl:when>
        <!-- s polozkama -->
        <xsl:otherwise>
			<xsl:if test="inv:invoiceSummary">
          		<sumCelkem><xsl:value-of select="java:flexibee.Tool.round(sum(inv:invoiceDetail/inv:invoiceItem/inv:homeCurrency/typ:priceSum) + inv:invoiceSummary/inv:homeCurrency/typ:round/typ:priceRound, '3')"/></sumCelkem>
			</xsl:if> <!-- inv:invoiceSummary -->
      
          <polozkyFaktury removeAll="true">
            <xsl:for-each select="inv:invoiceDetail/inv:invoiceItem">
              <faktura-vydana-polozka>
				<xsl:if test="inv:invoiceHeader/inv:id">
                	<id>ext:POHODA-FVPOL:<xsl:value-of select="substring(../../inv:invoiceHeader/inv:date,0,5)"/>-<xsl:value-of select="inv:id"/></id>
				</xsl:if>
                <nazev><xsl:value-of select="inv:text"/></nazev>
                
                <xsl:if test="number(inv:quantity) = 0">
                    <typPolozkyK>typPolozky.ucetni</typPolozkyK>
                </xsl:if>
                <mnozMj><xsl:value-of select="inv:quantity"/></mnozMj>
                <xsl:if test="inv:unit != ''">
                    <mj if-not-found="null">code:<xsl:value-of select="java:flexibee.Tool.toUpper(inv:unit)"/></mj>
                </xsl:if>

                <!-- inv:coefficient -->
                <xsl:choose>
	                <xsl:when test="inv:rateVAT = 'high'"><typSzbDphK>typSzbDph.dphZakl</typSzbDphK></xsl:when>
	                <xsl:when test="inv:rateVAT = 'low'"><typSzbDphK>typSzbDph.dphSniz</typSzbDphK></xsl:when>
	                <xsl:when test="inv:rateVAT = 'none'"><typSzbDphK>typSzbDph.dphOsv</typSzbDphK></xsl:when>
                </xsl:choose>
            
                <slevaPol><xsl:value-of select="inv:discountPercentage"/></slevaPol>
                
                <xsl:choose>
                  <xsl:when test="(inv:payVAT = true or inv:payVAT = 'true')">
  					        <typCenyDphK>typCeny.sDph</typCenyDphK>
                  </xsl:when>
                  <xsl:otherwise>
                    <typCenyDphK>typCeny.bezDph</typCenyDphK>
                  </xsl:otherwise>
                </xsl:choose>

                <xsl:choose>
                  <xsl:when test="inv:foreignCurrency/typ:unitPrice != '' and inv:foreignCurrency/typ:unitPrice != '0'">
                    <cenaMj><xsl:value-of select="inv:foreignCurrency/typ:unitPrice"/></cenaMj>
                  </xsl:when>
                  <xsl:otherwise>
                    <cenaMj><xsl:value-of select="inv:homeCurrency/typ:unitPrice"/></cenaMj>
                  </xsl:otherwise>
                </xsl:choose>
                
				<xsl:if test="inv:homeCurrency/typ:price">
                	<sumZkl><xsl:value-of select="inv:homeCurrency/typ:price"/></sumZkl>
				</xsl:if>
				<xsl:if test="inv:homeCurrency/typ:priceVAT">
                	<sumDph><xsl:value-of select="inv:homeCurrency/typ:priceVAT"/></sumDph>
				</xsl:if>
				<xsl:if test="inv:homeCurrency/typ:priceSum">
                	<sumCelkem><xsl:value-of select="inv:homeCurrency/typ:priceSum"/></sumCelkem>
				</xsl:if>
				<xsl:if test="inv:foreignCurrency/typ:price">
                	<sumZklMen><xsl:value-of select="inv:foreignCurrency/typ:price"/></sumZklMen>
				</xsl:if>
				<xsl:if test="inv:foreignCurrency/typ:priceVAT">
                	<sumDphMen><xsl:value-of select="inv:foreignCurrency/typ:priceVAT"/></sumDphMen>
				</xsl:if>
				<xsl:if test="inv:foreignCurrency/typ:priceSum">
                	<sumCelkemMen><xsl:value-of select="inv:foreignCurrency/typ:priceSum"/></sumCelkemMen>
				</xsl:if>
            
                <poznam><xsl:value-of select="inv:note"/></poznam>
                <kod><xsl:value-of select="inv:code"/></kod>
                <!-- inv:guarantee -->
            
                <xsl:if test="inv:stockItem/typ:store/typ:id != ''">
                    <sklad if-not-found="null">ext:POHODA-SKLAD:<xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="inv:stockItem/typ:store/typ:id"/></sklad>
                </xsl:if>
                <xsl:if test="inv:stockItem/typ:stockItem/typ:id != ''">
                    <cenik if-not-found="null">ext:POHODA-CENIK:<xsl:value-of select="$yearExtIdPrefix"/><xsl:value-of select="inv:stockItem/typ:stockItem/typ:id"/></cenik>
                </xsl:if>
              </faktura-vydana-polozka>
	          </xsl:for-each>
	        </polozkyFaktury>
	    
        </xsl:otherwise>
      </xsl:choose>
      
      <xsl:if test="inv:invoiceHeader/inv:liquidation/typ:date != ''">
        <hotovostni-uhrada>
          <uhrazujiciDokl>ext:POHODA-UHRADAVF:<xsl:value-of select="substring(inv:invoiceHeader/inv:date,0,5)"/>-<xsl:value-of select="inv:invoiceHeader/inv:id"/></uhrazujiciDokl>
          <pokladna>code:<xsl:value-of select="java:flexibee.Tool.join('PREVOD',inv:invoiceSummary/inv:foreignCurrency/typ:currency/typ:ids,'-')"/></pokladna>
          <typDokl>code:STANDARD</typDokl> <!-- typ vytvářeného pokladního dokladu -->
          <datumUhrady><xsl:value-of select="inv:invoiceHeader/inv:liquidation/typ:date"/></datumUhrady>
          
          <!-- inv:liquidation - zbyva uhradit -->
      <!--<inv:liquidation>
					<typ:date>-->
          <castka>
          <xsl:choose>
            <!-- mena -->
            <xsl:when test="inv:invoiceSummary/inv:foreignCurrency/typ:currency/typ:ids != ''">
            
              <xsl:choose>
                <!-- zbyva neco uhradit -->
                <xsl:when test="inv:invoiceHeader/inv:liquidation/typ:amountHome != ''">
                  <xsl:value-of select="java:flexibee.Tool.round(($castkaDokl - inv:invoiceHeader/inv:liquidation/typ:amountHome) * inv:invoiceSummary/inv:foreignCurrency/typ:amount div inv:invoiceSummary/inv:foreignCurrency/typ:rate, '3')"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="java:flexibee.Tool.round($castkaDokl * inv:invoiceSummary/inv:foreignCurrency/typ:amount div inv:invoiceSummary/inv:foreignCurrency/typ:rate, '3')"/>
                </xsl:otherwise>
              </xsl:choose>
            
            </xsl:when>
            <xsl:otherwise>
            
              <xsl:choose>
                <!-- zbyva neco uhradit -->
                <xsl:when test="inv:invoiceHeader/inv:liquidation/typ:amountHome != ''">
                  <xsl:choose>
                    <!-- bezpolozkova faktura -->
                    <xsl:when test="count(inv:invoiceDetail/inv:invoiceItem) = 0">
                      <xsl:value-of select="java:flexibee.Tool.round($castkaDokl - inv:invoiceHeader/inv:liquidation/typ:amountHome, '3')"/>
                    </xsl:when>
                    <!-- s polozkama -->
                    <xsl:otherwise>
                      <xsl:value-of select="java:flexibee.Tool.round(sum(inv:invoiceDetail/inv:invoiceItem/inv:homeCurrency/typ:priceSum) + inv:invoiceSummary/inv:homeCurrency/typ:round/typ:priceRound - inv:invoiceHeader/inv:liquidation/typ:amountHome, '3')"/>
                    </xsl:otherwise>
                  </xsl:choose>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="$castkaDokl "/>
                </xsl:otherwise>
              </xsl:choose>
            
            </xsl:otherwise>
          </xsl:choose>
          </castka>
          
        </hotovostni-uhrada>
	    </xsl:if>
    </faktura-vydana>
    
    </xsl:if>
  </xsl:template>
  
</xsl:stylesheet>
