--------------------------------------------------------------------------------
-- Bug 18550 – [WinStrom] Složky mzdy a aktualizace
--------------------------------------------------------------------------------

-- složkám které jsou na osobu vymažeme pracovní poměr pokud by tam náhodou byl
ALTER TABLE pmzdsloz DISABLE TRIGGER pmzdslozupdatedatumvypoctu;

UPDATE pmzdsloz as S SET idpracpom = null WHERE (select naosobu from pcismzdsloz where s.idcismzdsloz = idcismzdsloz) = true;

ALTER TABLE pmzdsloz ENABLE TRIGGER pmzdslozupdatedatumvypoctu;


-- doplnění sloupců na hlavičku pracovního poměru
ALTER TABLE posobahlav ADD COLUMN osbcis character varying(20);
ALTER TABLE posobahlav ADD COLUMN jmeno character varying(255);
ALTER TABLE posobahlav ADD COLUMN prijmeni character varying(255);
ALTER TABLE posobahlav ADD COLUMN titul character varying(255);

UPDATE posobahlav as H SET osbcis = (select osbcis from posoba where idosobahlav = H.idosobahlav limit 1),
  jmeno = (select jmeno from posoba where idosobahlav = H.idosobahlav limit 1),
  prijmeni = (select prijmeni from posoba where idosobahlav = H.idosobahlav limit 1),
  titul = (select titul from posoba where idosobahlav = H.idosobahlav limit 1);

ALTER TABLE posobahlav ALTER COLUMN osbcis SET NOT NULL;


-- doplnění sloupců na hlavičku osoby
ALTER TABLE ppracpomhlav ADD COLUMN kod character varying(20);
ALTER TABLE ppracpomhlav ADD COLUMN nazev character varying(255);
ALTER TABLE ppracpomhlav ADD COLUMN hlavni boolean DEFAULT false;

UPDATE ppracpomhlav as H SET kod = (select kod from ppracpom where idpracpomhlav = H.idpracpomhlav limit 1),
  nazev = (select nazev from ppracpom where idpracpomhlav = H.idpracpomhlav limit 1),
  hlavni = (select hlavni from ppracpom where idpracpomhlav = H.idpracpomhlav limit 1);

ALTER TABLE ppracpomhlav ALTER COLUMN kod SET NOT NULL;


-- trigger prenasejici jmeno apod na hlavicku
CREATE OR REPLACE FUNCTION posobaupdatehlavicka()
  RETURNS trigger AS $$
begin
  if (NEW.platido is null) then
    UPDATE posobahlav SET osbcis = NEW.osbcis, jmeno = NEW.jmeno, prijmeni = NEW.prijmeni, titul = NEW.titul WHERE idosobahlav = NEW.idosobahlav; 
  end if;
  
  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.posobaupdatehlavicka() OWNER TO %firmaRole%;

CREATE TRIGGER posobaupdatehlavicka AFTER INSERT OR UPDATE ON posoba
  FOR EACH ROW EXECUTE PROCEDURE posobaupdatehlavicka();


-- trigger prenasejici datumy aktivnosti pracovniho pomeru z jednoho nastaveni na ostatni a na hlavicku
CREATE OR REPLACE FUNCTION ppracpomupdateaktivni()
  RETURNS trigger AS $$
begin
  update ppracpomhlav set aktivniod = NEW.aktivniod, aktivnido = NEW.aktivnido 
    where idpracpomhlav = NEW.idpracpomhlav and 
      (((aktivniod is null) <> (NEW.aktivniod is null)) or (aktivniod is not null and aktivniod <> NEW.aktivniod) or
      ((aktivnido is null) <> (NEW.aktivnido is null)) or (aktivnido is not null and aktivnido <> NEW.aktivnido));
  
  update ppracpom set aktivniod = NEW.aktivniod, aktivnido = NEW.aktivnido 
    where idpracpomhlav = NEW.idpracpomhlav and 
      (((aktivniod is null) <> (NEW.aktivniod is null)) or (aktivniod is not null and aktivniod <> NEW.aktivniod) or
      ((aktivnido is null) <> (NEW.aktivnido is null)) or (aktivnido is not null and aktivnido <> NEW.aktivnido));
  
  if (NEW.platido is null) then
    update ppracpomhlav set kod = NEW.kod, nazev = NEW.nazev, hlavni = NEW.hlavni where idpracpomhlav = NEW.idpracpomhlav 
      and (kod <> NEW.kod or nazev <> NEW.nazev or hlavni <> NEW.hlavni);
  end if;
  
  -- pokud vkladame nove nastaveni nebo doslo ke zmene bez zmeny datumu aktivnosti zkontrolujeme smeny
  if (tg_op = 'INSERT') then
    perform pgeneratemzdslozforpracpom(NEW.idpracpomhlav);
  end if;
  if (tg_op = 'UPDATE') then
   if not (((OLD.aktivniod is null) <> (NEW.aktivniod is null)) or (OLD.aktivniod is not null and OLD.aktivniod <> NEW.aktivniod) or
       ((OLD.aktivnido is null) <> (NEW.aktivnido is null)) or (OLD.aktivnido is not null and OLD.aktivnido <> NEW.aktivnido)) then
      perform pgeneratemzdslozforpracpom(NEW.idpracpomhlav);
    end if;
  end if;
  
  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.ppracpomupdateaktivni() OWNER TO %firmaRole%;


--------------------------------------------------------------------------------
-- Bug 17557 – [WinStrom] Aktualizace kalkulačky na rok 2010
--------------------------------------------------------------------------------

create or replace function runupgrade()
    returns void as $$
declare
    stat character varying(10);
    pocet integer;
begin
  select a.uuid into stat from nnastav n  left join utyporg u on u.idtyporg = n.idtyporg left join astaty a on a.idstatu = u.idstatu
    where ((select max(platioddata) from nnastav) is null or (select max(platioddata) from nnastav) = platioddata);
  
  -- kalkulacku aktualizujeme jen pro cechy
  if (stat = 'CZ_CZ') then
-- zacatek ceskeho bloku
-- update slozek
UPDATE pcismzdsloz SET vyznamk = null WHERE IdCisMzdSloz = 3;
UPDATE pcismzdsloz SET vyznamk = null, pracovni = false WHERE IdCisMzdSloz = 69;
UPDATE pcismzdsloz SET vyznamk = null WHERE IdCisMzdSloz = 70;
UPDATE pcismzdsloz SET nazev = 'Přísp. firmy na penz. pojištění (pro uzaměstnance - fixní )' WHERE IdCisMzdSloz = 126;
UPDATE pcismzdsloz SET nazev = 'Stravné fixní' WHERE IdCisMzdSloz = 132;
UPDATE pcismzdsloz SET nazev = 'Stravné dle odprac. dnů ' WHERE IdCisMzdSloz = 133;
UPDATE pcismzdsloz SET vyznamk = null, pracovni = false WHERE IdCisMzdSloz = 171;
UPDATE pcismzdsloz SET vyznamk = null WHERE IdCisMzdSloz = 177;
UPDATE pcismzdsloz SET nazev = 'Přísp. firmy na životní. pojištění (pro uzaměstnance - fixní )' WHERE IdCisMzdSloz = 180;
UPDATE pcismzdsloz SET vyznamk = null, pracovni = true WHERE IdCisMzdSloz = 232;
UPDATE pcismzdsloz SET vyznamk = null, pracovni = true WHERE IdCisMzdSloz = 233;
UPDATE pcismzdsloz SET vyznamk = null WHERE IdCisMzdSloz = 252;
UPDATE pcismzdsloz SET vyznamk = null WHERE IdCisMzdSloz = 253;
UPDATE pcismzdsloz SET castkahod = 0.0 WHERE IdCisMzdSloz = 257;
UPDATE pcismzdsloz SET nazev = 'Uživatelsky definovaná srážka' WHERE IdCisMzdSloz = 276;


-- update inicializacnich radek kalkulacky
-- update radek kalkulacky
-- nastavime hromadnou radku do hlavicky
UPDATE pmzdcalchlav SET idradkahromadne = null WHERE idmzdcalchlav = 1;
DELETE FROM pmzdcalc WHERE idmzdcalchlav = 1;

INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (1, '2010-01-12 00:00:00.000', '3', '----- Časová (hodinová) mzda do odpracované doby', true, 65, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny', 'dnyPrac;dnyKal;dnySvatek;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 18, 63);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (5, '2010-01-12 00:00:00.000', '3', '----- Úkolová mzda  do odpracované doby', true, 66, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny', 'dnyPrac;dnyKal;dnySvatek;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 19, 63);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (7, '2010-01-12 00:00:00.000', '5', '----- Časová (hodinová) mzda', true, 72, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 18, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (8, '2010-01-12 00:00:00.000', 'HRUBÁ MZDA', 'Patří do základu pro výpočet pracocně právního průměru', true, 71, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 17, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (9, '2010-01-12 00:00:00.000', '5', '----- Podílová (provizní) mzda', true, 73, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 20, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (11, '2010-01-12 00:00:00.000', '5', '----- Měsíční odměna', true, 75, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 23, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (24, '2010-01-12 00:00:00.000', '5', '----- Prémie % ze základní mzdy', true, 80, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 25, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (27, '2010-01-12 00:00:00.000', '6', '----- Odměna členů statutárního orgánu-nerezident', true, 148, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 32, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (29, '2010-01-12 00:00:00.000', '6', 'NEpatří do základu pro výpočet pracocně právního průměru - Odměna členů statutárního orgánu', true, 147, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 31, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (30, '2010-01-12 00:00:00.000', '5', '----- Odměna členů statutárního orgánu-nerezident', true, 81, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 32, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (31, '2010-01-12 00:00:00.000', '6', '----- Odměna k živ, prac. jubileu, odchodu do důch.', true, 152, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 29, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (32, '2010-01-12 00:00:00.000', '5', '----- Odměna podle zákona o vynálezech a ZN', true, 82, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 30, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (33, '2010-01-12 00:00:00.000', '5', '----- Mimořádná odměna ', true, 83, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 24, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (34, '2010-01-12 00:00:00.000', '5', '----- Mzda za práci přesčas', true, 88, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 22, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (35, '2010-01-12 00:00:00.000', '5', '----- Ostatní odměny', true, 89, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 33, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (37, '2010-01-12 00:00:00.000', '5', '----- Prémie pevnou částkou ', true, 100, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 26, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (38, '2010-01-12 00:00:00.000', '5', '----- Podíly % ze zisku - základu ', true, 101, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 28, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (40, '2010-01-12 00:00:00.000', '5', '----- Prémie % z ukazatele - základu ', true, 102, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 27, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (41, '2010-01-12 00:00:00.000', '5', '----- do hrubé mzdy', true, 123, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 36, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (42, '2010-01-12 00:00:00.000', '5', '----- Osobní příplatek', true, 133, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 41, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (43, '2010-01-12 00:00:00.000', '5', '----- do hrubé mzdy', true, 125, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 39, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (44, '2010-01-12 00:00:00.000', '5', '----- do hrubé mzdy', true, 129, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 35, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (45, '2010-01-12 00:00:00.000', '5', '----- Příplatek za rozdělenou směnu', true, 135, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 37, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (46, '2010-01-12 00:00:00.000', '5', '----- do hrubé mzdy', true, 117, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 38, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (47, '2010-01-12 00:00:00.000', '5', '----- Příplatek za vedení a zastupování', true, 136, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 42, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (48, '2010-01-12 00:00:00.000', '5', '----- do hrubé mzdy', true, 120, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 34, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (49, '2010-01-12 00:00:00.000', '5', '----- Zvláštní příplatek', true, 134, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 40, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (51, '2010-01-12 00:00:00.000', '6', '----- Odstupné, odchodné, odbytné', true, 150, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 44, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (52, '2010-01-12 00:00:00.000', '6', '----- Cestovní náhrady do limit', true, 151, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 45, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (53, '2010-01-12 00:00:00.000', '6', '----- Cestovní náhrady nadlimit', true, 153, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 46, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (55, '2010-01-12 00:00:00.000', '6', '----- Srážka za přečerpanou dovolenou', true, 154, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 48, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (56, '2010-01-12 00:00:00.000', '6', '----- Doplatek do průměrného výdělku', true, 155, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 49, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (57, '2010-01-12 00:00:00.000', '6', '----- Doplatek do minimální mzdy', true, 156, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 50, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (58, '2010-01-12 00:00:00.000', '6', '----- Náhrada škod podle zákoníku práce', true, 149, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 51, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (59, '2010-01-12 00:00:00.000', '6', '----- Jednorázová sociální výpomoc', true, 157, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 52, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (61, '2010-01-12 00:00:00.000', '6', '----- 1%  vstupní ceny vozu ', true, 158, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 54, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (62, '2010-01-12 00:00:00.000', '6', '----- Peněž dar z FKSP', true, 159, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 55, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (63, '2010-01-12 00:00:00.000', '6', '----- Naturálni mzda', true, 160, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 56, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (64, '2010-01-14 00:00:00.000', '6', '----- Příspěvek firmy na penzijní a životní pojištění zaměstnance v měsíci', true, 174, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 248, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (68, '2010-01-14 00:00:00.000', '8', '----- Základ pro průměrný výdělek', true, 199, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 90, 87);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (69, '2010-01-14 00:00:00.000', '8', '----- Nepatří do základu pro průměrný výdělek', true, 200, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 89, 87);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (70, '2010-01-14 00:00:00.000', '6', 'Příspěvek firmy na penzijní a životní pojištění do limitu', true, 214, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 249, 88);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (75, '2010-01-14 00:00:00.000', '8', '----- Odměna podle zákona o vynálezech a ZN', true, 189, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 30, 154);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (76, '2010-01-14 00:00:00.000', 'SOC.ZÁKLAD STD', 'Výpočet sociálky', true, 202, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 87, 162);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (78, '2010-01-14 00:00:00.000', '9', '----- Nepatří do základu pro sociální pojištění', true, 215, -1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 155, 162);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (79, '2010-01-14 00:00:00.000', 'ZDRAVOTNÍ POJIŠTĚNÍ', 'Výpočet zdravotky', true, 244, -1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 154, 163);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (80, '2010-01-14 00:00:00.000', '9', '---- Základ pro sociální pojištění po akceptování limitu', true, 230, 0.215, 1.0, 0.0, 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 99);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (81, '2010-01-14 00:00:00.000', '9', '---- Základ pro sociální pojištění  (pro všechny pracovní poměry) ', true, 231, 0.023, 1.0, 0.0, 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 100);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (82, '2010-01-14 00:00:00.000', '9', '---- Základ pro sociální pojištění  (pro všechny pracovní poměry) ', true, 232, 0.012, 1.0, 0.0, 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 101);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (83, '2010-01-14 00:00:00.000', '9', '---- Základ pro sociální pojištění  (pro všechny pracovní poměry) ', true, 233, 0.065, 1.0, 0.0, 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 95);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (86, '2010-01-14 00:00:00.000', 'SOC.POJ.FIRMA PRAC.', 'Soc. pojištění - Firma - důchodové  (pro všechny pracovní poměry) ', true, 234, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 99, 102);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (89, '2010-01-14 00:00:00.000', '9', '----- Sociálka výpočet', true, 239, 1.0, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 95, 98);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (92, '2010-01-14 00:00:00.000', '9', '----- Oprava soc. pojištění - zaměstnavatel', true, 238, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 76, 102);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (93, '2010-01-14 00:00:00.000', '9', '----- Oprava soc. pojištění - pracovník', true, 240, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 75, 98);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (94, '2010-01-14 00:00:00.000', '10', '----- Základ za všechny pracovní poměry', true, 246, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 163, 92);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (95, '2010-01-14 00:00:00.000', '10', '----- Zdravotní pojištění firma zaokrozhlená matematicky', true, 266, 0.09, 1.0, 0.0, 'zaokrJak.matem', 'zaokrNa.jednotky', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 202, 104);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (96, '2010-01-14 00:00:00.000', 'ZDRAV.POJ.PRAC.', '------ ZDRAV.POJ.PRAC.= ZDRAV.POJ.CELKEM - ZDRAV.POJ.FIRMA', true, 268, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 104, 103);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (97, '2010-01-14 00:00:00.000', '10', '----- Oprava zdrav. pojištění - zaměstnavatel', true, 276, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 78, 104);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (98, '2010-01-14 00:00:00.000', '10', '----- Zdravotka výpočet ', true, 277, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 77, 103);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (99, '2010-01-14 00:00:00.000', '12', 'Srážková daň', true, 320, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 87, 159);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (100, '2010-01-14 00:00:00.000', '11', '----- Nezdanitelné částky celkem', true, 287, -1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 88, 158);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (101, '2010-01-14 00:00:00.000', '11', '----- Oprava zálohy na daň', true, 319, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 82, 118);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (103, '2010-01-14 00:00:00.000', '11', '----- Oprava zdanitelných příjmů', true, 288, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 79, 158);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (104, '2010-01-14 00:00:00.000', '11', '----- Základ pro výpočet daně', true, 294, 0.15, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 107, 108);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (106, '2010-01-14 00:00:00.000', '11', '----- Sleva - poplatníka', true, 295, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 110, 117);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (107, '2010-01-14 00:00:00.000', '11', '----- Sleva - Student připravující se na budoucí povolání', true, 296, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 114, 117);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (108, '2010-01-14 00:00:00.000', '11', '----- Sleva - Osoba, za kterou platí zdrav. pojištění stát', true, 297, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 115, 117);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (109, '2010-01-14 00:00:00.000', '11', '----- Sleva - Držitel průkaz ZTP-P', true, 298, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 113, 117);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (110, '2010-01-14 00:00:00.000', '11', '----- Oprava slevy na dani celkem', true, 299, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 81, 117);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (111, '2010-01-14 00:00:00.000', '11', '----- Odpočet celkové slevy na dani', true, 305, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 117, 118);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (112, '2010-01-14 00:00:00.000', '13', '----- Soc. pojištění - pracovník   (pro všechny pracovní poměry) ', true, 328, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 98, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (113, '2010-01-14 00:00:00.000', '13', '----- Zdrav. pojištění - pracovník', true, 329, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 103, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (114, '2010-01-14 00:00:00.000', '13', '----- Hrubá mzda celkem pro všechny pracovní poměry', true, 326, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 167, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (115, '2010-01-12 00:00:00.000', '6', '----- 1%  vstupní ceny vozu ', true, 188, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 54, 156);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (116, '2010-01-12 00:00:00.000', '6', '----- Naturálni mzda', true, 187, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 56, 156);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (117, '2010-01-14 00:00:00.000', '13', '----- Nepatří do hrubé mzdy', true, 330, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 156, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (119, '2010-01-14 00:00:00.000', '9', '----- *', true, 223, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 162, 94);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (120, '2010-01-14 00:00:00.000', '9', '----- *', true, 243, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 87, 163);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (121, '2010-01-14 00:00:00.000', '9', '----- Sociální pojištění - oprava základu', true, 216, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 164, 162);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (122, '2010-01-14 00:00:00.000', '10', '----- Zdravotní pojištění = oprava základ', true, 245, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 165, 163);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (123, '2010-01-14 00:00:00.000', '11', '----- Základ pro výpočet daně ', true, 291, 1.0, 1.0, 0.0, 'zaklMzd;zaklMzd', 'zaklMzd;procMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 158, 107);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (124, '2010-01-14 00:00:00.000', 'DANĚ', 'Výpočet daně', true, 278, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 87, 158);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (125, '2010-01-14 00:00:00.000', '11', '----- Vypočtená daň', true, 304, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 108, 118);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (130, '2010-01-14 00:00:00.000', '11', 'Sociální pojištění - firma / zaměstnavatel', true, 289, 1.0, 0.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 102, 107);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (131, '2010-01-14 00:00:00.000', '11', '----- Zdrav. pojištění - zaměstnavatel', true, 292, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 104, 107);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (133, '2010-01-14 00:00:00.000', '8', '----- Hrubá mzda celkem pro všechny pracovní poměry', true, 201, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 87, 167);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (134, '2010-01-14 00:00:00.000', '9', '----- Soc. pojištění - Firma - nemocenské   (pro všechny pracovní poměry) ', true, 235, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 100, 102);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (135, '2010-01-14 00:00:00.000', '9', '----- Soc. pojištění - Firma - Stát.pol.zaměs.   (pro všechny pracovní poměry) ', true, 236, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 101, 102);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (136, '2010-01-14 00:00:00.000', '11', '----- Sleva - Dítě', true, 301, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 116, 189);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (139, '2010-01-14 00:00:00.000', '12', '----- Základ pro výpočet srážkové daně', true, 324, 0.15, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 157, 145);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (140, '2010-01-14 00:00:00.000', '12', '----- Oprava srážkové daně', true, 325, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 83, 145);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (145, '2010-01-14 00:00:00.000', '12', '----- Základ pro výpočet srážkové daně pro pracovní poměr', true, 321, 1.0, 1.0, 0.0, 'zaklMzd;zaklMzd', 'zaklMzd;procMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 159, 157);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (146, '2010-01-14 00:00:00.000', 'MZDA', 'Čistá mzda', true, 327, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 118, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (147, '2010-01-14 00:00:00.000', '13', '----- Srážková daň ', true, 332, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 145, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (172, '2010-01-14 00:00:00.000', '15', '----- 3. redukční hranice', true, 335, 0.3, 1.0, 0.0, 'prumNaHodNem', 'prumNaHodNem', 207.55, 414.93, 'mzdCalcOper.plus', false, 0, 1, 172, 175);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (173, '2010-01-14 00:00:00.000', '15', '----- Sumace redukčních hranic', true, 336, 1.0, 1.0, 0.0, 'prumNaHodNem', 'prumNaHodNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 173, 176);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (174, '2010-01-14 00:00:00.000', '15', '-----', true, 337, 1.0, 1.0, 0.0, 'prumNaHodNem', 'prumNaHodNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 174, 176);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (175, '2010-01-14 00:00:00.000', '15', '-----', true, 338, 1.0, 1.0, 0.0, 'prumNaHodNem', 'prumNaHodNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 175, 176);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (181, '2010-01-12 00:00:00.000', '1', '----- Karanténa  do neodpracované doby (čas)', true, 31, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 12, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (183, '2010-01-12 00:00:00.000', '1', '----- Nemoc  do neodpracované doby (čas)', true, 32, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 3, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (184, '2010-01-12 00:00:00.000', '1', '----- Nemoc - nepracovní úraz  do neodpracované doby (čas)', true, 33, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 13, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (185, '2010-01-12 00:00:00.000', '1', '----- Nemoc - pracovní úraz  do neodpracované doby (čas)', true, 34, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 14, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (186, '2010-01-12 00:00:00.000', '1', '----- Nemoc z povolání do neodpracované doby (čas)', true, 35, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 15, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (187, '2010-01-12 00:00:00.000', '1', '----- Překážky z důvodů obecného zájmu  do neodpracované doby (čas)', true, 36, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 11, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (188, '2010-01-12 00:00:00.000', '1', '----- Absence neomluvená  do neodpracované doby (čas)', true, 37, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 5, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (189, '2010-01-12 00:00:00.000', '1', '----- Volno placené  do neodpracované doby (čas)', true, 38, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 6, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (190, '2010-01-12 00:00:00.000', '1', '----- Volno neplacené  do neodpracované doby (čas)', true, 39, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 7, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (191, '2010-01-12 00:00:00.000', '1', '----- Důležité osobní překážky v práci  do neodpracované doby (čas)', true, 40, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 10, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (192, '2010-01-12 00:00:00.000', 'NEPŘÍTOMNOST - SUM ', '----- Ošetřování člena rodiny  do neodpracované doby (čas)', true, 41, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 4, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (193, '2010-01-14 00:00:00.000', 'REDUKOVANÝ PRŮMĚR', '----- Výpočet redukovaného průměru pro náhradu za nemoc - 1. redukční hranice', true, 333, 0.9, 1.0, 0.0, 'prumNaHodNem', 'prumNaHodNem', 0.0, 138.43, 'mzdCalcOper.plus', false, 0, 1, 172, 173);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (194, '2010-01-14 00:00:00.000', '15', '----- 2. redukční hranice', true, 334, 0.6, 1.0, 0.0, 'prumNaHodNem', 'prumNaHodNem', 138.43, 207.55, 'mzdCalcOper.plus', false, 0, 1, 172, 174);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (195, '2010-01-14 00:00:00.000', 'NÁHRADY ZA NEMOC', '----- Přesun redukovaného PPP do  výpočtu náhrady za nemoc', true, 344, 1.0, 0.0, 0.0, 'prumNaHodNem;prumNaHodNem', 'castMzd;castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 176, 70);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (196, '2010-01-14 00:00:00.000', '15', '----- Přesun redukovaného PPP do  výpočtu náhrady karantény', true, 353, 1.0, 0.0, 0.0, 'prumNaHodNem;prumNaHodNem', 'castMzd;castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 176, 177);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (197, '2010-03-23 00:00:00.000', 'NÁHR.NEMOC 1-3', '-----     Výpočet pčesahu nemoci přes 24 hodiny první 3 dny', true, 339, 1.0, 0.0, 0.0, 'hodiny', 'procMzd', 24.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 69, 69);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (198, '2010-01-14 00:00:00.000', '15', '----- Výpočet náhrady', true, 345, 0.6, 0.0, 0.0, 'hodiny', 'castkaHod', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 70, 70, 70);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (200, '2010-01-14 00:00:00.000', 'SOC.FIRMA REFUNDACE', '...', true, 355, 0.5, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 177, 178);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (201, '2010-01-14 00:00:00.000', '15------------------', '----- Zaokrouhlení na koruny nahoru', true, 347, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 70, 70);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (202, '2010-01-14 00:00:00.000', '15', '----- Výpočet refundace náhrady', true, 346, 0.5, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 70, 178);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (206, '2010-01-14 00:00:00.000', '15', '...', true, 354, 0.6, 0.0, 0.0, 'hodiny', 'castkaHod', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 177, 177, 177);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (207, '2010-01-14 00:00:00.000', 'SOC.POJ.CELKEM', '...', true, 356, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 9.9999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 178, 217);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (208, '2010-01-12 00:00:00.000', '2', 'Koeficient vypočtený z toho, co zbývá na měsíční mzdu (fond-neodpracovaná doba-hodnová mzda-úkolová mzda)', true, 47, 1.0, 1.0, 0.0, 'dnyKal;dnyPrac;dnySvatek;hodiny;hodiny;hodinySvatek', 'dnyKal;dnyPrac;dnySvatek;hodiny;castMzd;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 188, 179);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (209, '2010-01-12 00:00:00.000', 'ODPR.DOBA VYPOČ.', '----- Vypočtená odpracovaná doba = od fondu je odečtena  neodpracovaná doba', 'doplněno odečtení svátku obsažených v nepřítonosti', true, 50, -1.0, 1.0, 0.0, 'dnyKal;dnyPrac;dnySvatek;hodiny;hodinySvatek', 'dnyKal;dnyPrac;dnySvatek;hodiny;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 16, 179);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (211, '2010-03-19 00:00:00.000', 'POMĚR.MĚSÍČNÍ MZDA', 'Měsíční mzda ', true, 67, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 17, 188, 17);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (213, '2010-01-14 00:00:00.000', '15', '----- Náhrada mzdy za nemoc', true, 358, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 70, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (214, '2010-01-14 00:00:00.000', '15', '----- Náhrada mzdy za karanténu', true, 359, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 171, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (215, '2010-01-14 00:00:00.000', '15', '----- Náhrada mzdy za karanténu', true, 360, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 177, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (216, '2010-01-12 00:00:00.000', '3', '----- Odpracovaná doba za minulé čtvrtletí', '', true, 62, 1.0, 0.0, 0.0, 'hodiny', 'hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.obdobi', 3, 1, 179, 183);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (217, '2010-01-12 00:00:00.000', 'PRAC.PRÁVNÍ PRŮMER', '----- Suma základu pro průměrný výdělek za minulé čtvrtletí', '', true, 61, 1.0, 0.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.obdobi', 3, 1, 90, 182);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (221, '2010-03-19 00:00:00.000', '16', '----- Sumace dovolené od začátku roku', '', true, 370, 1.0, 1.0, 0.0, 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 2, 185);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (222, '2010-03-19 00:00:00.000', 'DOVOLENÁ', '----- Dovolená', 'sumaa odpracované doby za minulé čtvrtletí', true, 368, 1.0, 1.0, 0.0, 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 184, 186);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (223, '2010-03-19 00:00:00.000', '16', '----- Počáteční satv dovolené - vybráno od začátku roku', 'sumaa odpracované doby za minulé čtvrtletí', true, 376, -1.0, 1.0, 0.0, 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', true, 0, 1, 185, 186);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (225, '2010-01-14 00:00:00.000', '16', 'Dovolená', '', true, 170, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodiny', 'prumNaHodNem', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 2, 172, 2);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (226, '2010-01-12 00:00:00.000', '2', 'Odpracovaná doba celkem - rozdíl mezi fondem pracovní doby a neodpracovanou dobou', true, 51, 1.0, 0.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 179, 17);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (227, '2010-01-14 00:00:00.000', '11', '----- Je-li daň záporná - vynuluje se', true, 308, 1.0, 0.0, 0.0, 'castMzd', 'castMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 118, 118);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (228, '2010-01-12 00:00:00.000', '1', '----- Dovolená do neodpracované doby (čas)', true, 30, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 2, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (234, '2010-01-12 00:00:00.000', '2', '----- odpracovaná doba  / fond = koeficient ke krácení měsíční a hodinové mzdy', true, 55, 1.0, 0.0, 0.0, 'hodiny', 'hodiny', 'procMzd', 0.0, 0.0, 'mzdCalcOper.lomeno', false, 0, 1, 179, 188, 188);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (236, '2010-01-12 00:00:00.000', '3', 'Měsíční mzda (plat)', true, 64, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny', 'dnyPrac;dnyKal;dnySvatek;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 17, 63);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (238, '2010-01-14 00:00:00.000', '11', '----- Přesunu výslednou daň do daňového bonusu', true, 310, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 118, 109);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (239, '2010-01-14 00:00:00.000', '11', 'Bonus', true, 306, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 189, 109);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (240, '2010-01-14 00:00:00.000', '11', '----- Omezení rozsahu bonusu na 100 - 4350 Kč', true, 311, 1.0, 0.0, 0.0, 'castMzd', 'castMzd', 0.0, 4350.0, 'mzdCalcOper.plus', false, 0, 1, 109, 109);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (241, '2010-01-14 00:00:00.000', '11', '----- když je bonus 0, pak koeficient  násobící daň = 1, jinak 0 (daň se vynuluje )', true, 312, 0.0, 1.0, 0.0, 'castMzd', 'procMzd', 0.0, 4350.0, 'mzdCalcOper.rovno', false, 0, 1, 109, 190);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (245, '2010-01-14 00:00:00.000', '11', '----- Nulování daně na základě nenulového bonusu', true, 316, 1.0, 0.0, 0.0, 'castMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 118, 190, 118);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (247, '2010-01-14 00:00:00.000', '11', '----- Daňové zvýhodnění na děti', true, 317, 1.0, 0.0, 0.0, 'castMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 189, 190, 191);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (249, '2010-01-14 00:00:00.000', '11', '----- Odečtení slevy ne děti, když není bonus', true, 318, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 191, 118);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (250, '2010-01-14 00:00:00.000', '9', '---- Přidání počátku ', true, 226, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.rokPred', 0, 1, 196, 199);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (251, '2010-01-14 00:00:00.000', '9', '---- Suma sociálky za minulé měsíce', true, 225, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.rokPred', 0, 1, 201, 199);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (252, '2010-01-14 00:00:00.000', '9', '---- Přidání aktuálního měsíce', true, 227, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 94, 199);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (253, '2010-01-14 00:00:00.000', '9', '---- Odečtu od limitu sumu vyýpočtového základu od začátku roku', true, 228, -1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 1707048.0, 9.99999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 199, 201);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (254, '2010-01-14 00:00:00.000', '9', '---- Výpočet toho co zbyde do limitu aktuální měsíc', true, 229, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 94, 201);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (256, '2010-03-19 00:00:00.000', '16', '----- Přičtení aktuálního měsíce', 'suma za minulé měsíce', true, 369, 1.0, 1.0, 0.0, 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.rokPred', 0, 1, 2, 185);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (258, '2010-01-14 00:00:00.000', '10', '---- Základ pro zdravotní pojištění', true, 247, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.rokPred', 0, 1, 202, 204);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (259, '2010-01-14 00:00:00.000', '10', '---- Základ pro zdravotního pojištění - hodnota základu z předchozího zaměstnání', true, 248, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.rokPred', 0, 1, 198, 204);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (260, '2010-01-14 00:00:00.000', '10', '---- Základ pro zdravotní pojištění', true, 249, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 92, 204);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (261, '2010-01-14 00:00:00.000', '10', '---- Základ pro zdravotní pojištění od začátku roku', true, 250, -1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 1707048.0, 9.99999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 204, 202);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (262, '2010-01-14 00:00:00.000', '10', 'Základ pro zdravotní pojištění', true, 252, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 92, 202);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (272, '2010-01-12 00:00:00.000', '5', '----- výpočet základu', 'suma odpracované doby za minulé čtvrtletí', true, 121, 1.0, 0.0, 0.0, 'hodiny', 'prumNaHodNem', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 36, 172, 36);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (274, '2010-01-12 00:00:00.000', 'NOČNÍ PŘÍPLATEK', '-----  Procenta  *  základ = výsledek', 'suma odpracované doby za minulé čtvrtletí', true, 122, 0.01, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'procMzd', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 36, 36, 36);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (275, '2010-01-12 00:00:00.000', '5', '----- do hrubé mzdy', true, 113, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 216, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (278, '2010-01-12 00:00:00.000', '5', '-----  hodiny  *  průměr =  základ', 'suma odpracované doby za minulé čtvrtletí', true, 111, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodiny', 'prumNaHodNem', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 216, 172, 216);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (280, '2010-01-12 00:00:00.000', '5', '-----  Procenta  *  základ = výsledek', 'suma odpracované doby za minulé čtvrtletí', true, 112, 0.01, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'procMzd', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 216, 216, 216);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (281, '2010-01-12 00:00:00.000', '5', '----- výpočet základu', 'suma odpracované doby za minulé čtvrtletí', true, 115, 1.0, 0.0, 0.0, 'hodiny', 'prumNaHodNem', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 38, 172, 38);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (282, '2010-01-12 00:00:00.000', 'PŘÍPLATEK ZA PŘESČAS', '----- základ x procenta', '', true, 116, 0.01, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 38, 38, 38);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (288, '2010-01-12 00:00:00.000', '5', '----- výpočet základu', 'suma odpracované doby za minulé čtvrtletí', true, 118, 1.0, 0.0, 0.0, 'hodiny', 'prumNaHodNem', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 34, 172, 34);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (290, '2010-01-12 00:00:00.000', 'PŘÍPLATEK ZA S+N', '----- základ x procenta', 'suma odpracované doby za minulé čtvrtletí', true, 119, 0.01, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'procMzd', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 34, 34, 34);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (291, '2010-01-12 00:00:00.000', 'PŘÍPL.ZA PROSTŘEDÍ', '-----  Kč/hod  *  hodiny = výsledek', true, 128, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castkaHod', 'hodiny', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 35, 35, 35);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (296, '2010-01-12 00:00:00.000', 'POHOTOVOST MIMO', '-----  Kč/hod  *  hodiny = výsledek', true, 126, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodiny', 'castkaHod', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 205, 205, 205);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (297, '2010-01-12 00:00:00.000', '5', '----- do hrubé mzdy', true, 127, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 205, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (307, '2010-03-23 00:00:00.000', '17', '----- Sumace sociálního pojištění  D', true, 433, 1.0, 0.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 98, 217);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (308, '2010-03-23 00:00:00.000', '17', '----- Sumace sociálního pojištění  C', true, 435, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 229, 217);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (310, '2010-03-19 00:00:00.000', 'ZÁVĚR', '----- Sumace zdravotního pojištěni', true, 377, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 103, 218);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (311, '2010-03-19 00:00:00.000', '17', '----- Sumace zdravotního pojištěni', true, 378, 1.0, 1.0, 0.0, 'castMzd;zaklMzd', 'castMzd;zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 104, 218);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (320, '2010-01-14 00:00:00.000', '9', 'Hrubá mzda celkem', true, 217, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 87, 221);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (321, '2010-01-14 00:00:00.000', '9', '----- Základ pro sociální pojištění  - pro pracovní poměry platící jen DP - společníci, jednatelé atd.  ', true, 220, 0.215, 1.0, 0.0, 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 221, 222);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (322, '2010-01-14 00:00:00.000', '9', '----- Základ pro sociální pojištění  - pro pracovní poměry platící jen DP - společníci, jednatelé atd.  ', true, 221, 0.065, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 221, 223);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (323, '2010-01-14 00:00:00.000', '9', '----- Nepatří do základu pro sociální pojištění', true, 218, -1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 155, 221);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (324, '2010-01-14 00:00:00.000', '9', '----- Sociální pojištění - oprava základu', true, 219, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 164, 221);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (325, '2010-01-14 00:00:00.000', '9', 'Soc. pojištění - Firma - pro JD', true, 237, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 222, 102);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (326, '2010-01-14 00:00:00.000', '9', 'Soc. pojištění - Zaměstnanec -JD', true, 241, 1.0, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 223, 98);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (327, '2010-01-14 00:00:00.000', '9', 'Základ pro sociální pojištění  - pro pracovní poměry platící jen DP - společníci, jednatelé atd.  ', true, 242, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 221, 94);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (328, '2010-03-19 00:00:00.000', '17', '----- Sumace náhrady za nemoc', true, 379, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.obdProplat', 0, 1, 171, 226);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (329, '2010-03-19 00:00:00.000', '17', '----- Sumace náhrady za nemoc', true, 380, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.obdProplat', 0, 1, 177, 226);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (330, '2010-03-19 00:00:00.000', '17', 'Náhrada mzdy za nemoc  - první 3 dny', true, 381, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.obdProplat', 0, 1, 69, 226);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (331, '2010-03-19 00:00:00.000', '17', '----- Sumace náhrady za nemoc', true, 382, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.obdProplat', 0, 1, 70, 226);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (332, '2010-01-12 00:00:00.000', '3', 'Čtvrtletní suma základu pro průměrný výdělek', 'sumaa odpracované doby za minulé čtvrtletí', true, 63, 1.0, 0.0, 0.0, 'castMzd', 'hodiny', 'prumNaHodNem', 0.0, 0.0, 'mzdCalcOper.lomeno', false, 0, 1, 182, 183, 172);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (333, '2010-01-14 00:00:00.000', 'NÁHR.KARANTÉNA 4-10', '...', true, 357, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 177, 177);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (336, '2010-01-12 00:00:00.000', '4', 'Odpracovaná doba celkem - rozdíl mezi fondem pracovní doby a neodpracovanou dobou', true, 69, 1.0, 0.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 179, 18);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (339, '2010-01-12 00:00:00.000', '4', 'Hodinová mzda', true, 70, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castkaHod', 'hodiny', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 18, 179, 18);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (341, '2010-01-12 00:00:00.000', '1', 'Dny před nástupem (měsíci) do zaměstnání pro výpočet podílu měsíční nebo hodinové mzdy ', true, 29, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 287, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (342, '2010-01-14 00:00:00.000', '8', '----- Odstupné, odchodné, odbytné', true, 190, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 44, 154);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (343, '2010-01-14 00:00:00.000', '8', '----- Odměna k životnímu, pracobnímu jubileu, odchodu do důchodu', true, 191, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 29, 154);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (345, '2010-01-14 00:00:00.000', '8', '----- Náhrada škod podle zákoníku práce', true, 192, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 51, 154);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (346, '2010-01-14 00:00:00.000', '8', '----- Jednorázová sociální výpomoc', true, 193, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 52, 154);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (347, '2010-01-14 00:00:00.000', '8', '----- Odstupné, odchodné, odbytné', true, 194, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 44, 155);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (348, '2010-01-14 00:00:00.000', '8', '----- Odměna k životnímu, pracobnímu jubileu, odchodu do důchodu', true, 195, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 29, 155);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (349, '2010-01-14 00:00:00.000', '8', '----- Odměna podle zákona o vynálezech a ZN', true, 196, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 30, 155);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (350, '2010-01-14 00:00:00.000', '8', '----- Náhrada škod podle zákoníku práce', true, 197, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 51, 155);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (351, '2010-01-14 00:00:00.000', '8', '----- Jednorázová sociální výpomoc', true, 198, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 52, 155);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (353, '2010-01-14 00:00:00.000', '11', 'Základ pro výpočet daně - superhubá mzda', true, 293, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.stovky', 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 107, 107);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (356, '2010-01-14 00:00:00.000', 'BONUS -', '----- záporný bonus', true, 314, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 109, 228);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (358, '2010-03-23 00:00:00.000', '17', '----- Sumace sociálního pojištění  A', true, 432, 1.0, 0.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 102, 229);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (359, '2010-03-23 00:00:00.000', '17', '----- Sumace sociálního pojištění  B', true, 434, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 181, 229);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (361, '2010-01-14 00:00:00.000', '11', '----- inicialůizace slevy', true, 279, 2070.0, 0.0, 0.0, 'procMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 110, 110, 110);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (362, '2010-01-14 00:00:00.000', '11', '----- inicialůizace slevy', true, 280, 335.0, 0.0, 0.0, 'procMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 114, 114, 114);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (363, '2010-01-14 00:00:00.000', '11', '----- inicializace slevy', true, 281, 0.0, 0.0, 0.0, 'procMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 115, 115, 115);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (364, '2010-01-14 00:00:00.000', '11', '----- inicializace slevy', true, 282, 1345.0, 0.0, 0.0, 'procMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 113, 113, 113);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (365, '2010-01-14 00:00:00.000', '11', '----- inicializace slevy', true, 284, 0.0, 0.0, 967.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 116, 116);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (367, '2010-01-14 00:00:00.000', '11', '----- inicializace slevy', true, 285, 210.0, 0.0, 0.0, 'procMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 111, 111, 111);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (368, '2010-01-14 00:00:00.000', '11', '----- inicializace slevy', true, 286, 420.0, 0.0, 0.0, 'procMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 112, 112, 112);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (369, '2010-01-14 00:00:00.000', '11', '----- Sleva na invalidní důchod 1. a 2. stupně', true, 302, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 111, 117);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (370, '2010-01-14 00:00:00.000', '11', '----- Sleva na invalidní důchod 3. stupně', true, 303, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 112, 117);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (377, '2010-01-12 00:00:00.000', 'NÁHRADA ZA SVÁTEK', 'Náhráda za svátek', true, 109, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodinySvatek', 'prumNaHodNem', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 21, 172, 21);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (379, '2010-03-19 00:00:00.000', 'NÁHR.NEMOC 1-3', '----- Přesun redukovaného PPP do  výpočtu náhrady za nemoc', true, 340, 1.0, 0.0, 0.0, 'prumNaHodNem', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 176, 69);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (380, '2010-03-23 00:00:00.000', 'NÁHR.NEMOC 1-3', 'Náhrada mzdy za nemoc  - první 3 dny', true, 341, 0.6, 0.0, 0.0, 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 69, 69);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (381, '2010-03-19 00:00:00.000', '15', 'Náhrada mzdy za nemoc  - první 3 dny', true, 342, 0.5, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 69, 178);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (382, '2010-03-19 00:00:00.000', 'NÁHR.NEMOC 1-3', 'Náhrada mzdy za nemoc  - první 3 dny', true, 343, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 69, 69);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (383, '2010-03-19 00:00:00.000', 'NÁHR.KARANTÉNA 1-3', 'Náhrada mzdy za karanténu - první 3 dny', true, 348, 1.0, 0.0, -24.0, 'hodiny', 'procMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 171, 171);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (384, '2010-03-19 00:00:00.000', 'NÁHR.KARANTÉNA 1-3', '----- Přesun redukovaného PPP do  výpočtu náhrady za nemoc', true, 349, 1.0, 0.0, 0.0, 'prumNaHodNem', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 176, 171);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (385, '2010-03-19 00:00:00.000', 'NÁHR.KARANTÉNA 1-3', 'Náhrada mzdy za karanténu - první 3 dny', true, 350, 0.6, 0.0, 0.0, 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 171, 171);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (386, '2010-03-19 00:00:00.000', 'NÁHR.KARANTÉNA 1-3', 'Náhrada mzdy za karanténu - první 3 dny', true, 352, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 171, 171);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (387, '2010-03-19 00:00:00.000', '15', 'Náhrada mzdy za karanténu - první 3 dny', true, 351, 0.5, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 171, 178);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (388, '2010-03-19 00:00:00.000', '4', 'Odpracovaná doba celkem - rozdíl mezi fondem pracovní doby a neodpracovanou dobou', true, 383, 1.0, 0.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 179, 18);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (389, '2010-01-14 00:00:00.000', 'ZDR.ZÁKL.PRAC.', 'Základ pro výpočet zdravotního pojištění firmy ', true, 253, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 202, 234);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (390, '2010-01-14 00:00:00.000', 'ZDR.POJ.NEPL.VOLNO', 'Zvýšení základu pro výpočet ZP pro zeměstnance o poměrný základ za neplacené volno', true, 262, 0.135, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 106, 106);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (391, '2010-01-14 00:00:00.000', 'ZDR.NEOML.ABSENCE', 'Zvýšení základu pro výpočet ZP pro zeměstnance o poměrný základ za neomluvenou absenci', true, 263, 0.135, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 105, 105);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (392, '2010-01-14 00:00:00.000', 'ZDR.ZÁKL.PRAC.', 'Doplatek do minimílního  vyměřovacího základu zdravotního pojištění', true, 264, 1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 93, 234);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (393, '2010-01-14 00:00:00.000', 'ZDR.POJ.NEPL.VOLNO', '------ 8000 do základu', true, 254, 0.0, 0.0, 8000.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 106, 106);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (394, '2010-01-14 00:00:00.000', '10', '----- Kopie stejných hodnot do absence', true, 256, 1.0, 0.0, 0.0, 'castkaDen', 'castkaDen', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 106, 105);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (395, '2010-03-19 00:00:00.000', '10', '----- Poměrný základ pro doplatek ZDR do minimální mzdy ', 'Hodnotu minimální mzdy násobím keficientem stejným pro měsíční mzdu ', true, 259, 8000.0, 0.0, 0.0, 'zaokrJak.matem', 'zaokrNa.jednotky', 'prumNaDenNem', '', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 188, 93);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (397, '2010-01-14 00:00:00.000', '10', '------ 8000 / počet dnů = částka na den', true, 255, 1.0, 0.0, 0.0, 'zaklMzd', 'dnyKal', 'castkaDen', 0.0, 0.0, 'mzdCalcOper.lomeno', false, 0, 1, 106, 188, 106);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (399, '2010-01-14 00:00:00.000', '10', 'Základ = dny neplaceného volna * částka na den (8000 / kal.dny)', true, 257, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castkaDen', 'dnyKal', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 106, 7, 106);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (401, '2010-01-14 00:00:00.000', '10', 'Zdravotní  pojištění za neomluvenou absenci', true, 258, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castkaDen', 'dnyKal', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 105, 5, 105);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (402, '2010-01-14 00:00:00.000', '10', 'Výpočet rozdílu oproti vypočtenému základu pracovníka', true, 260, -1.0, 1.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 234, 93);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (404, '2010-01-14 00:00:00.000', '10', 'Nulování když je prázdný', true, 261, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 93, 93);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (405, '2010-03-19 00:00:00.000', 'DOVOLENÁ VYBRÁNO', 'Odečet dovolené za neomluvenou absenci', 'sumaa odpracované doby za minulé čtvrtletí', true, 374, 1.0, 1.0, 0.0, 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 235, 185);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (407, '2010-01-14 00:00:00.000', '10', 'Základ pro zdravotní pojištění', true, 269, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 202, 104);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (408, '2010-01-14 00:00:00.000', '10', 'Základ pro výpočet zdravotního pojištění, který nepřekračuje roční limit', true, 273, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 234, 103);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (409, '2010-01-12 00:00:00.000', '5', '----- Úkolová mzda ', true, 74, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 19, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (410, '2010-03-19 00:00:00.000', 'ODEČET DOVOL.ZA ABS.', 'Absence neomluvená', 'sumaa odpracované doby za minulé čtvrtletí', true, 373, 1.0, 0.0, 1.0, 'dnyPrac', 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 5, 236, 235);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (411, '2010-01-12 00:00:00.000', 'POHOTOVOST', '-----  Kč/hod  *  hodiny = výsledek', true, 124, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castkaHod', 'hodiny', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 39, 39, 39);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (413, '2010-03-19 00:00:00.000', 'SRÁŽKY CELKEM', 'Výživné ', true, 384, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 119, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (414, '2010-03-19 00:00:00.000', '18', 'Náhrada škod', true, 385, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 120, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (416, '2010-03-19 00:00:00.000', '18', 'Pojištění ', true, 386, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 125, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (418, '2010-03-19 00:00:00.000', '18', 'Penzijní pojištění zaměstnance', true, 387, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 127, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (420, '2010-03-19 00:00:00.000', '18', 'Odbory částka ', true, 388, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 128, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (421, '2010-03-19 00:00:00.000', '18', 'Odbory % ze mzdy', true, 392, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 129, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (422, '2010-03-19 00:00:00.000', '18', 'Životní pojištění', true, 393, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 130, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (423, '2010-03-19 00:00:00.000', '18', 'Osobní účet ', true, 407, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 131, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (424, '2010-03-19 00:00:00.000', '18', 'Stravné vypočet dle odprac. dnů ', true, 397, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 133, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (425, '2010-03-19 00:00:00.000', '18', 'Srážky% z hrubé mzdy ', true, 400, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 134, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (426, '2010-03-19 00:00:00.000', '18', 'Čistá mzda ', true, 390, 1.0, 0.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 140, 129);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (427, '2010-03-19 00:00:00.000', '18', 'Odbory % ze mzdy', true, 391, 0.01, 0.0, 0.0, 'zaokrJak.matem', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 129, 129, 129);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (428, '2010-03-19 00:00:00.000', '18', 'Hrubá mzda celkem ', true, 394, 1.0, 0.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 167, 134);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (429, '2010-03-19 00:00:00.000', '18', 'Srážky% z hrubé mzdy ', true, 399, 0.01, 1.0, 0.0, 'zaokrJak.matem', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 134, 134, 134);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (430, '2010-03-19 00:00:00.000', '18', 'Spoření', true, 406, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 123, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (431, '2010-03-19 00:00:00.000', '18', 'Půjčky ', true, 401, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 124, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (432, '2010-03-19 00:00:00.000', '18', 'Přeplatky ', true, 402, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 121, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (433, '2010-03-19 00:00:00.000', '18', 'Ostattní exekuce', true, 403, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 122, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (434, '2010-03-19 00:00:00.000', '18', 'Náhrada škod', true, 404, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 120, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (435, '2010-03-19 00:00:00.000', '18', 'Stravné', true, 405, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 132, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (436, '2010-03-19 00:00:00.000', 'DOBÍRKA', 'Celkové srážky', true, 418, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 135, 139);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (437, '2010-01-12 00:00:00.000', '6 - 1', 'Prostoj 100%', true, 184, 1.0, 1.0, 0.0, 'hodiny', 'prumNaHodNem', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 240, 172, 240);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (438, '2010-01-12 00:00:00.000', '6 - 2', 'Prostoj 100%', true, 185, 0.01, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 240, 240, 240);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (439, '2010-01-12 00:00:00.000', '6 - 3', 'Prostoj 100%', true, 186, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 240, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (440, '2010-01-12 00:00:00.000', 'PROSTOJ  100%', '----- Pracovně právní hodinový průměr do prostoje', true, 183, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'prumNaHodNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 240);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (445, '2010-01-12 00:00:00.000', 'PROSTOJ  60%', '----- Pracovně právní hodinový průměr do prostoje', true, 175, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'prumNaHodNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 238);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (446, '2010-01-12 00:00:00.000', '6 - 1', 'Prostoj 60% nebo částečná nezaměstnanost', true, 176, 1.0, 1.0, 0.0, 'hodiny', 'prumNaHodNem', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 238, 172, 238);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (447, '2010-01-12 00:00:00.000', '6 - 2', 'Prostoj 60% nebo částečná nezaměstnanost', true, 177, 0.01, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 238, 238, 238);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (448, '2010-01-12 00:00:00.000', '6 - 3', 'Prostoj 60% nebo částečná nezaměstnanost', true, 178, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 238, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (449, '2010-01-12 00:00:00.000', 'PROSTOJ  80%', '----- Pracovně právní hodinový průměr do prostoje', true, 179, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'prumNaHodNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 239);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (450, '2010-01-12 00:00:00.000', '6 - 2', 'Prostoj 80%', true, 180, 1.0, 1.0, 0.0, 'hodiny', 'prumNaHodNem', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 239, 172, 239);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (451, '2010-01-12 00:00:00.000', '6 - 3', 'Prostoj 80%', true, 181, 0.01, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 239, 239, 239);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (452, '2010-01-12 00:00:00.000', '6 - 3', 'Prostoj 80%', true, 182, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 239, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (454, '2010-03-23 00:00:00.000', 'CELKOVÁ DAŇ', 'Srážková daň ', true, 422, 1.0, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 145, 242);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (455, '2010-03-19 00:00:00.000', 'CELKOVÁ DAŇ', 'Záloha na daň - výsledek po slevách a opravách', true, 398, 1.0, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 118, 242);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (456, '2010-03-19 00:00:00.000', 'POMĚR.ČÁST DOVOLENÉ', '----- Pořadí dne nástupu do zaměstnání - přepočet na zbývá do konce roku', 'pořadový den nástupu - vyhozena 1 z k2', true, 364, -1.0, 0.0, 365.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'dnyKal', 'dnyKal', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 243, 246);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (457, '2010-03-19 00:00:00.000', '17', '----- Počet dnú do konce roku - výpočet koeficientu', 'koeficient pro výpočet zbývající dovolené', true, 365, 1.0, 1.0, 0.0, 'dnyKal', 'dnyKal', 'procMzd', 0.0, 0.0, 'mzdCalcOper.lomeno', false, 0, 1, 246, 245, 246);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (458, '2010-03-19 00:00:00.000', 'DOVOLENÁ POČÁTEK', 'Nárok na dovolenou', 'koeficient pro výpočet zbývající dovolené', true, 366, 2.0, 0.0, 0.0, 'zaokrJak.matem', 'zaokrNa.jednotky', 'dnyPrac', 'procMzd', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 244, 246, 184);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (459, '2010-01-12 00:00:00.000', '365', '----- počet dní v roce', 'koeficient pro výpočet zbývající dovolené', true, 6, 0.0, 0.0, 365.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'dnyKal', '', 'dnyKal', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 245, 245);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (460, '2010-01-14 00:00:00.000', 'PEN.+ŽIV.FIRMA SUMA', 'Příspěvek firmy na penzijní a životní pojištění zaměstnance v měsíci', true, 207, 1.0, 0.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.rokPred', 0, 1, 248, 247);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (461, '2010-01-14 00:00:00.000', '*', 'Příspěvek firmy na penzijní a životní pojištění zaměstnance v měsíci', true, 208, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 248, 247);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (462, '2010-01-14 00:00:00.000', '*', 'Příspěvek firmy na penzijní a životní pojištění zaměstnance celkem za minulé měsíce', true, 209, -1.0, 0.0, 0.0, 'castMzd', 'castMzd', 24000.0, 9.99999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 247, 249);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (463, '2010-01-14 00:00:00.000', '*', 'Příspěvek firmy na penzijní a životní pojištění zaměstnance v měsíci', true, 210, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 248, 249);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (464, '2010-01-14 00:00:00.000', '1', '% příspěvku firmy na penzijní pojištění zaměstnance', true, 203, 0.01, 0.0, 0.0, 'procMzd', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 'mzdCalcSuma.rokPred', 0, 1, 237, 167, 250);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (465, '2010-01-14 00:00:00.000', '2', 'Příspěvek firmy / zamětnavatele na penzijní pojištění zaměstnance procentem', true, 204, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 250, 248);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (466, '2010-01-14 00:00:00.000', 'PENZIJ.+ŽIVOT.', 'Příspěvek firmy / zamětnavatele na životní  pojištění zaměstnance fixní', true, 205, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 180, 248);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (467, '2010-01-14 00:00:00.000', '4', 'Příspěvek firmy / zamětnavatele na penzijní pojištění zaměstnance fixní', true, 206, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 126, 248);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (468, '2010-01-14 00:00:00.000', 'HRUBA MZDA CELKEM ', '---- do nákladů firmy (hrubá mzda ) - příspěvek firmy na penzijní a životní pojištění do limitu', true, 213, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 249, 167);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (471, '2010-01-14 00:00:00.000', 'SLEVA NA DÍTĚ ZTP/P', '----- inicilizace slevy', true, 283, 0.0, 0.0, 967.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 251, 251);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (472, '2010-01-14 00:00:00.000', '11', 'Sleva na dítě ZTP/P', true, 300, 1.0, 0.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 251, 189);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (473, '2010-01-14 00:00:00.000', 'PENZ.+ŽIV.DANĚNO', 'Příspěvek firmy na penzijní a životní pojištění zaměstnance v měsíci', true, 211, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 248, 65);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (474, '2010-01-14 00:00:00.000', 'PENZ.+ŽIV.DANĚNO', 'Příspěvek firmy na penzijní a životní pojištění do limitu', true, 212, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 9.999999999999E12, 'mzdCalcOper.plus', false, 0, 1, 249, 65);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (475, '2010-01-14 00:00:00.000', '10', 'Penzijní připojištění Skupina.Dan - Daněno', true, 251, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 65, 92);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (476, '2010-01-14 00:00:00.000', 'SOC.POJ.ZÁKLAD', 'Penzijní připojištění Skupina.Dan - Daněno', true, 224, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 65, 94);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (477, '2010-01-14 00:00:00.000', '11', 'Penzijní připojištění Skupina.Dan - Daněno', true, 290, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 65, 107);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (478, '2010-01-14 00:00:00.000', '13', 'Příspěvek firmy na penzijní a životní pojištění do limitu', true, 331, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 249, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (479, '2010-01-21 00:00:00.000', 'SVÁTEK', 'Fond pracovní doby', true, 3, 1.0, 0.0, 0.0, 'hodinySvatek;dnySvatek;hodinySvatek;dnySvatek', 'hodiny;dnyPrac;hodinySvatek;dnySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 1, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (480, '2010-01-20 00:00:00.000', 'NEPATŘÍ DO PPP ', 'Dovolená', '', true, 171, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 2, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (481, '2010-01-20 00:00:00.000', 'NEPATŘÍ DO PPP ', 'Náhráda za svátek', true, 110, 1.0, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 21, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (482, '2010-01-20 00:00:00.000', '3', 'Měsíční mzda  - výpočet částky za hodinu', true, 68, 1.0, 0.0, 0.0, 'castMzd', 'hodiny', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.lomeno', false, 0, 1, 17, 17, 17);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (484, '2010-01-20 00:00:00.000', 'PRESČAS', 'Měsíční mzda ', true, 84, 1.0, 0.0, 0.0, 'castkaHod', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 17, 22);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (485, '2010-01-20 00:00:00.000', 'PRESČAS', 'Mzda za práci přesčas', true, 87, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castkaHod', 'hodiny', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 22, 22, 22);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (486, '2010-01-20 00:00:00.000', 'NEČERPANÁ DOVOLENÁ', 'Proplacení nevyčerpané dovolené', '', true, 172, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodiny', 'prumNaHodNem', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 47, 172, 47);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (487, '2010-01-20 00:00:00.000', 'NEPATŘÍ DO PPP ', 'Proplacení nevyčerpané dovolené', '', true, 173, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 47, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (488, '2010-03-19 00:00:00.000', 'DOVOLENÁ VYBRÁNO', 'Proplacení nevyčerpané dovolené', '', true, 371, 1.0, 1.0, 0.0, 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 47, 185);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (489, '2010-01-20 00:00:00.000', 'NÁHRADA ZA SVÁTEK', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', true, 103, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 21);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (490, '2010-01-20 00:00:00.000', 'PŘIPLATEK ZA SVÁTEK', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', true, 114, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 38);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (491, '2010-01-20 00:00:00.000', 'PŘÍPLATEK ZA S+N', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', true, 104, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 34);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (492, '2010-01-20 00:00:00.000', 'PŘÍPLATEK ZA PŘESČAS', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', true, 105, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 216);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (493, '2010-01-20 00:00:00.000', 'NEČERPANÁ DOVOLENÁ', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', true, 106, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 47);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (494, '2010-01-20 00:00:00.000', 'DOVOLENÁ', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', true, 107, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 2);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (495, '2010-03-19 00:00:00.000', 'DOBÍRKA', 'Záloha mimořádná', true, 419, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 137, 139);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (496, '2010-03-19 00:00:00.000', 'DOBÍRKA', 'Záloha řádná', true, 420, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 136, 139);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (497, '2010-01-20 00:00:00.000', 'NOČNÍ PŘÍPLATEK', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', true, 108, 1.0, 0.0, 0.0, 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 36);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (498, '2010-01-21 00:00:00.000', 'OBECNÝ ZÁJEM', 'Překážky z důvodů obecného zájmu placené ', '', true, 167, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodiny', 'prumNaHodNem', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 11, 172, 11);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (499, '2010-01-21 00:00:00.000', '6', 'Překážky z důvodů obecného zájmu placené ', '', true, 168, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 11, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (500, '2010-01-21 00:00:00.000', '6', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', '', true, 169, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 11);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (501, '2010-01-21 00:00:00.000', 'PŘEKÁŽKY OSOBNÍ', 'Důležité osobní překážky v práci  (svatba, narození dítěte, vyšetření ve zdravotnickém zařízení aj. § 128) ', '', true, 161, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodiny', 'prumNaHodNem', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 10, 172, 10);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (502, '2010-01-21 00:00:00.000', '6', 'Důležité osobní překážky v práci  (svatba, narození dítěte, vyšetření ve zdravotnickém zařízení aj. § 128) ', '', true, 162, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 10, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (503, '2010-01-21 00:00:00.000', '6', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', '', true, 163, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 172, 10);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (504, '2010-01-21 00:00:00.000', 'VOLNO PLACENÉ', 'Volno placené', '', true, 164, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodiny', 'prumNaHodNem', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 6, 172, 6);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (505, '2010-01-21 00:00:00.000', 'NEPATŘÍ DO PPP ', 'Volno placené', '', true, 165, 1.0, 1.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 6, 89);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (508, '2010-01-21 00:00:00.000', 'VOLNO PLACENÉ', 'Pracovně právní hodinový průměr pro náhradu mzdy za nemoc, dovolenou ', '', true, 166, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'prumNaHodNem', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 6);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (509, '2010-01-21 00:00:00.000', '2', 'Fond pracovní  doby v aktuálním měsíci', true, 48, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodinySvatek;dnySvatek;hodinySvatek;dnySvatek', '', 'hodinySvatek;dnySvatek;hodiny;dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 1, 21);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (510, '2010-01-25 00:00:00.000', '2', '----- Vynulování hodin náhrady za svátek', 'Do pole procMzd si nastavim hodontu - 1 bude náhrada za svátek 0 nebude náhrada', true, 49, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'hodinySvatek;dnySvatek', 'procMzd', 'hodinySvatek;dnySvatek', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 21, 21, 21);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (511, '2010-01-22 00:00:00.000', 'KOEF. PRO MĚS.MZDU ', '----- Připočtení dnů ve svátek', true, 1, 1.0, 0.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', '', 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 1, 188);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (512, '2010-01-22 00:00:00.000', 'KOEF. PRO MĚS.MZDU ', '----- Fond pracovní  doby v aktuálním měsíci', true, 2, 1.0, 1.0, 0.0, 'hodinySvatek;dnySvatek', '', 'hodiny;dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 1, 188);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (513, '2010-01-22 00:00:00.000', '11', 'Základ pro výpočet daně - superhubá mzda', true, 309, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 107, 118);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (514, '2010-01-23 00:00:00.000', 'DOBÍRKA', 'Čistá mzda ', true, 363, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 140, 139);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (516, '2010-03-23 00:00:00.000', '9', '---- Základ pro sociální pojištění po akceptování limitu', true, 423, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 99);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (517, '2010-03-23 00:00:00.000', 'SOC.FIR.NEMOC', '---- Základ pro sociální pojištění po akceptování limitu', true, 424, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 100);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (518, '2010-03-23 00:00:00.000', 'SOC.FIR.NEZAM.', '---- Základ pro sociální pojištění po akceptování limitu', true, 425, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 101);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (519, '2010-03-23 00:00:00.000', 'SOC.POJ.CELKEM', '---- Základ pro sociální pojištění po akceptování limitu', true, 426, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 217);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (520, '2010-03-23 00:00:00.000', 'SOC.POJ.PRACOVNÍK', '---- Základ pro sociální pojištění po akceptování limitu', true, 427, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 98);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (521, '2010-03-23 00:00:00.000', 'SOC.FIR.DŮCHOD', '---- Základ pro sociální pojištění po akceptování limitu', true, 428, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 99);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (522, '2010-01-27 00:00:00.000', '15', 'Daňový bonus', true, 361, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 109, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (523, '2010-03-19 00:00:00.000', 'STRAVNÉ VYPOČTENÉ', 'Stravné vypočet dle odprac. dnů ', true, 396, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'procMzd', 'dnyPrac', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 133, 133, 133);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (524, '2010-03-19 00:00:00.000', 'STRAVNÉ VYPOČTENÉ', 'Odpracovaná doba', true, 395, 1.0, 0.0, 0.0, 'dnyPrac', '', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 179, 133);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (525, '2010-01-27 00:00:00.000', 'PRESČAS', 'Úkolová mzda ', true, 86, 1.0, 0.0, 0.0, 'castkaHod', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 19, 22);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (526, '2010-01-27 00:00:00.000', 'PRESČAS', 'Hodinová mzda', true, 85, 1.0, 0.0, 0.0, 'castkaHod', '', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 18, 22);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (527, '2010-01-27 00:00:00.000', '1', '----- Mateřská dovolená (vstupuje do vyloučených dob v ELDP)', true, 42, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 150, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (528, '2010-01-27 00:00:00.000', '1', '----- Rodičovská dovolená  (nevstupuje do vyloučených dob v ELDP) ', true, 45, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 151, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (529, '2010-01-28 00:00:00.000', 'OSOBNÍ PŘÍPLATEK', 'Koeficient vypočtený z toho, co zbývá na měsíční mzdu (fond-neodpracovaná doba-hodnová mzda-úkolová mzda)', true, 130, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'procMzd', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 188, 41, 41);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (530, '2010-01-28 00:00:00.000', '15', 'Přeplatek daně z ročního zúčtování', 'Posunuto z konce sem a zároveň byla složka PŘEPLATEK DANĚ označena jako společná pro pracovní poměry', true, 362, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 254, 140);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (531, '2010-01-28 00:00:00.000', 'PRÉMIE %', '----- Prémie % ze základní mzdy', true, 76, 0.01, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 25, 25, 25);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (532, '2010-01-28 00:00:00.000', 'PRÉMIE % UKAZATELE', 'Prémie % z ukazatele / základu ', true, 77, 0.01, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 27, 27, 27);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (533, '2010-01-28 00:00:00.000', 'PODÍLOVÁ MZDA', 'Podílová (provizní) mzda', true, 78, 0.01, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 20, 20, 20);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (534, '2010-01-28 00:00:00.000', 'PODÍL NA ZISKU', 'Podíly % ze zisku / základu ', true, 79, 0.01, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 28, 28, 28);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (535, '2010-01-29 00:00:00.000', 'ZDRAV.POJ.PRAC.', 'Zvýšení základu pro výpočet ZP pro zeměstnance o poměrný základ za neplacené volno', true, 274, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 106, 103);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (536, '2010-01-29 00:00:00.000', 'ZDRAV.POJ.PRAC.', 'Zdravotní  pojištění za neomluvenou absenci', true, 275, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 105, 103);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (537, '2010-03-23 00:00:00.000', 'HRUBA MZDA CELKEM ', '1%  vstupní ceny vozu ', true, 429, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 54, 167);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (538, '2010-03-23 00:00:00.000', 'DÍLČÍ HRUBÁ MZDA', '1%  vstupní ceny vozu ', true, 430, -1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 54, 87);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (540, '2010-02-09 00:00:00.000', 'ZDR.DOPL.MIN.ZAKL.', 'Doplatek do minimílního  vyměřovacího základu zdravotního pojištění', true, 270, 0.135, 0.0, 0.0, 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 93, 93);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (541, '2010-02-09 00:00:00.000', 'ZDRAV.POJ.PRAC.', 'Doplatek do minimílního  vyměřovacího základu zdravotního pojištění', true, 271, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 93, 103);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (542, '2010-02-09 00:00:00.000', 'ZDRAV.POJ.PRAC.', 'Zdrav. pojištění - pracovník', true, 272, 1.0, 0.0, 0.0, 'zaokrJak.matem', 'zaokrNa.jednotky', 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 103, 103);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (543, '2010-02-10 00:00:00.000', 'ZÁKL.SRÁŽKOVÉ DANĚ', 'Sociální pojištění - firma před zaokrouhlením', '10.2.2010', true, 322, 1.0, 1.0, 0.0, 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 102, 157);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (544, '2010-02-10 00:00:00.000', 'ZÁKL.SRÁŽKOVÉ DANĚ', 'Zdravotní  pojištění - firma', '10.2.2010; 15.2.2010 - zrušeno zaokrouhlování základu srážkové daně na 100 Kč', true, 323, 1.0, 1.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'castMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 104, 157);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (545, '2010-02-26 00:00:00.000', 'HRUBA MZDA CELKEM ', 'Hrubá mzda celkem ', 'do konstatnty dám, zda je hrubá mzda menší než polovina minimální mzdy', true, 307, 4000.0, 0.0, 1.0, 'castMzd', 'procMzd', 0.0, 0.0, 'mzdCalcOper.mensiRovno', false, 0, 1, 167, 167);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (546, '2010-02-26 00:00:00.000', 'BONUS', 'Daňový bonus', 'nuluji bonus, když je hrubá pod 1/2 minimalní mzdy', true, 313, 1.0, 0.0, 0.0, 'castMzd', 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 109, 167, 109);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (547, '2010-02-27 00:00:00.000', 'ZŮČTOVÁNÍ DANĚ ', 'Přeplatek daně z ročního zúčtování', 'Posunuto z konce sem a zároveň byla složka PŘEPLATEK DANĚ označena jako společná pro pracovní poměry', true, 315, -1.0, 0.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 254, 255);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (548, '2010-02-25 00:00:00.000', 'CELKOVÁ NEPŘÍTOMNOST', 'Svátek', true, 46, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 'dnyPrac;dnyKal;dnySvatek;hodiny;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 256, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (549, '2010-02-26 00:00:00.000', '9', '----- -----***** inicializace plátce soc.pojištění ', 'pro dpp, malý rozsah do 2000 atd se nuluje', true, 222, 0.0, 1.0, 0.0, 'procMzd', 'procMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 162, 162);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (550, '2010-03-23 00:00:00.000', 'SOC.POJ.CELKEM', '----- *', true, 431, 1.0, 1.0, 0.0, 'procMzd', 'procMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 162, 217);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (551, '2010-02-26 00:00:00.000', '2', '----- Negace pole procmzd (z inicializace je 1 když je náhrada za svátek)', true, 52, 1.0, 0.0, 1.0, 'procMzd', 'procMzd', 0.0, 0.0, 'mzdCalcOper.rovno', false, 0, 1, 256, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (552, '2010-02-26 00:00:00.000', '2', '----- Přičtení svátku do odpracované doby když za něj není náhrada', true, 54, 1.0, 1.0, 0.0, 'hodinySvatek', '', 'hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 256, 179);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (553, '2010-02-26 00:00:00.000', '2', '----- vrácená pole ODPRACOVÁNO VÝPOČET  do původního stavu', true, 60, -1.0, 1.0, 0.0, 'hodinySvatek', '', 'hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 256, 179);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (554, '2010-02-26 00:00:00.000', '2', '----- nulování hodin svátek', true, 53, 1.0, 0.0, 0.0, 'procMzd', 'hodinySvatek', 'hodinySvatek', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 256, 256, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (555, '2010-03-06 00:00:00.000', 'SVÁTEK', 'Dny před nástupem (měsíci) do zaměstnání pro výpočet podílu měsíční nebo hodinové mzdy ', true, 5, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 287, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (556, '2010-03-06 00:00:00.000', 'PŘED NÁSTUPEM (PRAC)', 'Dny před nástupem (měsíci) do zaměstnání pro výpočet podílu měsíční nebo hodinové mzdy ', true, 7, 1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek', 'dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 287, 287);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (557, '2010-03-06 00:00:00.000', '5', '¨něco za něco', true, 137, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 257, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (558, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 138, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 258, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (559, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 139, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 259, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (560, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 140, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 260, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (561, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 141, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 261, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (562, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 142, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 262, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (563, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 143, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 263, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (564, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 144, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 264, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (565, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 145, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 265, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (566, '2010-03-06 00:00:00.000', '5', '----- Uživatelský příplatek', true, 146, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 266, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (567, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 90, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 267, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (568, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 91, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 268, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (569, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 92, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 269, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (570, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 93, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 270, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (571, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 94, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 271, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (572, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 95, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 272, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (573, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 96, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 273, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (574, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 97, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 274, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (575, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 98, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 275, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (576, '2010-03-06 00:00:00.000', '5', '----- Uživatelem zadaná odměna', true, 99, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 285, 90);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (577, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 408, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 276, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (578, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 409, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 277, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (579, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 410, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 278, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (580, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 411, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 279, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (581, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 412, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 280, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (582, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 413, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 281, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (583, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 414, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 282, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (585, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 415, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 283, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (586, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 416, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 284, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (587, '2010-03-19 00:00:00.000', '18', 'Uživatelsky definovaná srážka', true, 417, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 286, 135);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (588, '2010-03-06 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 8, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 3, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (589, '2010-03-06 00:00:00.000', 'ZDRAV.POJ.FIRMA', '----- Celkové zdravotní pojištění zaokrouhlené na koruny nahoru', true, 265, 0.135, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'zaklMzd', 'procMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 202, 104);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (590, '2010-03-06 00:00:00.000', 'ZDRAV.POJ.PRAC.', 'Zdravotní  pojištění - firma', true, 267, 1.0, 0.0, 0.0, 'procMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 104, 103);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (591, '2010-03-06 00:00:00.000', 'PŘED NÁSTUPEM (PRAC)', 'Dny před nástupem (měsíci) do zaměstnání pro výpočet podílu měsíční nebo hodinové mzdy ', true, 4, 1.0, 0.0, 0.0, 'dnyKal;dnyPrac;dnySvatek;hodiny;hodinySvatek', 'dnyKal;dnyPrac;dnySvatek;hodiny;hodinySvatek', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 227, 287);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (592, '2010-03-08 00:00:00.000', 'PŘÍPLATEK ZA VEDENÍ', 'Koeficient vypočtený z toho, co zbývá na měsíční mzdu (fond-neodpracovaná doba-hodnová mzda-úkolová mzda)', true, 131, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'procMzd', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 188, 42, 42);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (593, '2010-03-08 00:00:00.000', 'PRÉMIE PEVNÁ', 'Koeficient vypočtený z toho, co zbývá na měsíční mzdu (fond-neodpracovaná doba-hodnová mzda-úkolová mzda)', true, 132, 1.0, 0.0, 0.0, 'zaokrJak.nahoru', 'zaokrNa.jednotky', 'procMzd', 'zaklMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.krat', false, 0, 1, 188, 26, 26);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (595, '2010-03-19 00:00:00.000', 'DOVOLENÁ VYBRÁNO', 'Proplacení nevyčerpané dovolené', 'suma za minulé měsíce', true, 372, 1.0, 1.0, 0.0, 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.rokPred', 0, 1, 47, 185);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, sumtypk, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (596, '2010-03-19 00:00:00.000', 'DOVOLENÁ VYBRÁNO', 'Odečet dovolené za neomluvenou absenci', 'sumaa odpracované doby za minulé čtvrtletí', true, 375, 1.0, 1.0, 0.0, 'dnyPrac', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 'mzdCalcSuma.rokPred', 0, 1, 235, 185);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (597, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 10, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 4, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (598, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 11, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 7, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (599, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 12, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 12, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (600, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 13, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 14, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (601, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 14, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 150, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (602, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 15, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 151, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (603, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 16, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 13, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (604, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 17, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 15, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (605, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 18, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 5, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (606, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 19, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 6, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (607, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 20, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 152, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (608, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 21, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 238, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (609, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 22, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 239, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (610, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 23, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 240, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (611, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 24, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 241, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (612, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 25, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 153, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (613, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 26, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 9, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (614, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 27, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 10, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (615, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 28, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 11, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (616, '2010-03-11 00:00:00.000', '1', 'Mimo evidenci (pro všechny pracovní poměry) ', true, 43, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 152, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (617, '2010-03-11 00:00:00.000', '1', 'Mimo evidenci neomluveno (pro všechny pracovní poměry) ', true, 44, 1.0, 1.0, 0.0, 'dnyPrac;dnyKal;hodiny;dnySvatek;hodinySvatek', 'dnyPrac;dnyKal;hodiny;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 153, 16);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (618, '2010-03-11 00:00:00.000', 'SVÁTEK', '----- Odečtení  svátku obsaženého v nepřítomnosti od svátku  ve složce SVÁTEK', true, 9, -1.0, 1.0, 0.0, 'dnySvatek;hodinySvatek;dnySvatek;hodinySvatek', 'dnySvatek;hodinySvatek;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 2, 256);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (619, '2010-03-22 00:00:00.000', '2', '----- výpočet odpracopvané doby pro dopaltek ZP do 8000', true, 56, 1.0, 0.0, 0.0, 'dnyKal', '', 'prumNaDenNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 179, 188);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (620, '2010-03-22 00:00:00.000', '2', '----- výpočet odpracopvané doby pro dopaltek ZP do 8000', true, 57, 1.0, 1.0, 0.0, 'dnyKal', '', 'prumNaDenNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 2, 188);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (623, '2010-03-22 00:00:00.000', '2', '----- výpočet odpracopvané doby pro dopaltek ZP do 8000', true, 58, 1.0, 1.0, 0.0, 'dnyKal', '', 'prumNaDenNem', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 6, 188);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozin2, idmzdslozout)
 VALUES (624, '2010-03-22 00:00:00.000', '2', '----- výpočet odpracopvané doby pro dopaltek ZP do 8000', true, 59, 1.0, 0.0, 0.0, 'prumNaDenNem', 'dnyKal', 'prumNaDenNem', 0.0, 0.0, 'mzdCalcOper.lomeno', false, 0, 1, 188, 188, 188);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, zaokrjakk, zaokrnak, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (625, '2010-03-19 00:00:00.000', 'DOVOLENÁ POČÁTEK', 'Nárok na dovolenou - poměrná část', 'koeficient pro výpočet zbývající dovolené', true, 367, 0.5, 0.0, 0.0, 'zaokrJak.matem', 'zaokrNa.setiny', 'dnyPrac', '', 'dnyPrac', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 184, 184);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (627, '2010-03-19 00:00:00.000', 'NEMOC', 'Celková náhrada za nemoc', true, 389, 1.0, 0.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 226, 3);
INSERT INTO pmzdcalc (idmzdcalc, lastUpdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (628, '2010-03-23 00:00:00.000', '2', '---- Nulování částky mzdy v odpracováno výpočet', true, 421, 0.0, 0.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 179, 179);

PERFORM pg_catalog.setval('seq_pmzdcalc', 628, true);

-- nastavime hromadnou radku do hlavicky
UPDATE pmzdcalchlav SET idradkahromadne = 358 WHERE idmzdcalchlav = 1;


-- pracovni pomery
-- parametry pro typ prac pom


-- konec ceskeho bloku
  end if; 
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION runupgrade() OWNER TO %firmaRole%;

select runupgrade();

drop function runupgrade();


-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 276, 't');
